/// <reference types="webappsec-credential-management" />
/**
 * The configuration options for the CredentialManager cookie
 * @public
 */
export interface CredentialManagerCookieConfig {
    path: string;
    name: string;
    expires: number | Date;
    storePasswords?: boolean;
}
/**
 * The configuration for the CredentialManager
 * @public
 */
export interface CredentialManagerConfig {
    cookie: CredentialManagerCookieConfig;
}
/**
 * The DI key which can be used for explicit configuration by the host application
 * @internal
 */
export declare const CredentialManagerConfig: import("@microsoft/fast-foundation").InterfaceSymbol<CredentialManagerConfig>;
/**
 * Represents user credentials.
 * @public
 */
export type CredentialData = PasswordCredentialData & {
    password?: string;
};
/**
 * Represents options for retrieving credentials.
 * @public
 */
export type GetCredentialOptions = CredentialRequestOptions & {};
/**
 * Types of credentials supported.
 * @public
 */
export declare enum CredentialType {
    BASIC = "BASIC",
    SSO = "SSO",
    JWT = "JWT",
    REFRESH = "REFRESH",
    MFA = "MFA"
}
/**
 * @public
 */
export type BasicCredentials = {
    type: CredentialType & CredentialType.BASIC;
    username: string;
    password: string;
};
/**
 * @public
 */
export type SSOCredentials = {
    type: CredentialType & CredentialType.SSO;
    ssoToken: string;
};
/**
 * @public
 */
export type RefreshCredentials = {
    type: CredentialType & CredentialType.REFRESH;
    username: string;
    refreshToken: string;
};
/**
 * @public
 */
export type JWTCredentials = {
    type: CredentialType & CredentialType.JWT;
    jwt: string;
    domain: string;
};
/**
 * @remarks
 * Will be sourced from MFA_CODE in url params.
 * @public
 */
export type MFACredentials = {
    type: CredentialType & CredentialType.MFA;
    mfaToken: string;
};
/**
 * Union of all credential types.
 * @public
 */
export type Credentials = BasicCredentials | SSOCredentials | JWTCredentials | RefreshCredentials | MFACredentials;
//# sourceMappingURL=types.d.ts.map