import type { ACK } from './ACK';
/**
 * @public
 */
export interface Details {
    readonly SYSTEM: System;
    readonly HEARTBEAT_INTERVAL_SECS: number;
    readonly FAILED_LOGIN_ATTEMPTS: number;
    readonly REJECTED_LOGIN_ATTEMPTS: number;
    readonly LAST_LOGIN_DATETIME: number;
    readonly DAYS_TO_PASSWORD_EXPIRY: number;
    readonly PRODUCT: Product[];
}
/**
 * @public
 */
export interface System {
    readonly DATE: string;
}
/**
 * @public
 */
export interface Product {
    readonly NAME: string;
    readonly VERSION: string;
}
/**
 * @public
 */
export interface EVENT_LOGIN_AUTH_ACK extends ACK {
    /**
     * Keeping these 3 here for now as I'm assuming these DTOs will be autogenerated at some point and will contain these.
     */
    readonly SESSION_AUTH_TOKEN: string;
    readonly REFRESH_AUTH_TOKEN: string;
    readonly SESSION_ID: string;
    readonly USER_NAME: string;
    readonly UPDATE_QUEUE: string;
    readonly ZERO_MQ_PROXY_MODE_ENABLED: boolean;
    readonly ZERO_MQ_PROXY_INBOUND_PORT: number;
    readonly ZERO_MQ_PROXY_OUTBOUND_PORT: number;
    /**
     * @privateRemarks
     * This is not the actual "user", it is random JSON / key value pairs set by BE app devs.
     *
     * @example
     * ```json
     * "USER" : {
     *   "USER_TYPE" : "USER",
     *   "USER_ACCESS_TYPE" : "ALL",
     *   "ADDRESS_LINE1" : "JohnDoe Street",
     *   "TEST_CONFIGURATION" : "TEST"
     * }
     * ```
     */
    readonly USER: {
        [key: string]: any;
    };
    readonly DETAILS: Details;
    readonly PERMISSION: string[];
    readonly PROFILE: string[];
}
//# sourceMappingURL=EVENT_LOGIN_AUTH_ACK.d.ts.map