/**
 * LogoutUtility interface.
 *
 * @remarks
 * A utility to execute a logout flow via a route change.
 *
 * @example Import the utility into any component or logic you wish to invoke a logout from.
 * ```ts
 * import { LogoutUtility } from '@genesislcap/foundation-auth/logout';
 * ...
 * @LogoutUtility private logout: LogoutUtility;
 * ...
 * this.logout.run();
 * ```
 *
 * @public
 */
export interface LogoutUtility {
    run(): void;
}
/**
 * Default LogoutUtility.
 *
 * @public
 */
export declare class DefaultLogoutUtility implements LogoutUtility {
    /** @internal */
    private config;
    /** @internal */
    private user;
    /** {@inheritDoc LogoutUtility.run} */
    run(): void;
}
/**
 * LogoutUtility DI key.
 *
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 *
 * @internal
 */
export declare const LogoutUtility: import("@microsoft/fast-foundation").InterfaceSymbol<LogoutUtility>;
/**
 * Gets LogoutUtility from the DI container.
 *
 * @remarks
 * A utility method for host applications that are not using decorators or the DI container.
 *
 * @example
 * ```ts
 * import { getLogoutUtility, LogoutUtility } from '@genesislcap/foundation-auth/logout';
 * ...
 * private logout: LogoutUtility = getLogoutUtility();
 * ...
 * this.logout.run();
 * ```
 *
 * @public
 */
export declare function getLogoutUtility(): LogoutUtility;
//# sourceMappingURL=logout.d.ts.map