import { UUID } from '@genesislcap/foundation-utils';
import type { Credentials } from '../credential';
import type { EVENT_LOGIN_AUTH, EVENT_LOGIN_AUTH_ACK, EVENT_LOGIN_AUTH_NACK, EVENT_LOGIN_DETAILS_ACK } from '../dto';
import type { Product as DTOProduct, System as DTOSystem } from '../dto/EVENT_LOGIN_AUTH_ACK';
import type { LoginAck, LoginDetailsAck, LoginNack } from '../entity';
import type { Product as EntityProduct, System as EntitySystem } from '../entity/loginAck';
import { Mapper } from './types';
/**
 * LoginDTO type.
 * @public
 */
export type LoginDTO = EVENT_LOGIN_AUTH | EVENT_LOGIN_AUTH_ACK | EVENT_LOGIN_AUTH_NACK | EVENT_LOGIN_DETAILS_ACK;
/**
 * LoginEntity type.
 * @public
 */
export type LoginEntity = Credentials | LoginAck | LoginDetailsAck | LoginNack;
/**
 * isLoginAckDTO.
 * @param dto - Potential DTO.
 * @public
 */
export declare function isLoginAckDTO(dto: LoginDTO): dto is EVENT_LOGIN_AUTH_ACK;
/**
 * isLoginDetailsAckDTO.
 * @param dto - Potential DTO.
 * @public
 */
export declare function isLoginDetailsAckDTO(dto: LoginDTO): dto is EVENT_LOGIN_DETAILS_ACK;
/**
 * isLoginNackDTO.
 * @param dto - Potential DTO.
 * @public
 */
export declare function isLoginNackDTO(dto: LoginDTO): dto is EVENT_LOGIN_AUTH_NACK;
/**
 * isLoginAckEntity.
 * @param entity - Potential entity.
 * @public
 */
export declare function isLoginAckEntity(entity: LoginEntity): entity is LoginAck;
/**
 * isLoginDetailsAckEntity.
 * @param entity - Potential entity.
 * @public
 */
export declare function isLoginDetailsAckEntity(entity: LoginEntity): entity is LoginDetailsAck;
/**
 * isLoginNackEntity.
 * @param entity - Potential entity.
 * @public
 */
export declare function isLoginNackEntity(entity: LoginEntity): entity is LoginNack;
/**
 * LoginMapper interface.
 *
 * @remarks
 * An extensible mapper for converting between login DTOs and Entities, where you can normalise data, implement derived
 * fields, validation etc.
 *
 * @example Overriding the default mapper for your application. Note the interface is the key.
 * ```ts
 * import { DefaultLoginMapper, LoginMapper } from '@genesislcap/foundation-auth';
 * import { Container, Registration } from '@microsoft/fast-foundation';
 *
 * class MyLoginMapper extends DefaultLoginMapper {
 *     // modify logic
 * }
 *
 * @customElement({...})
 * export class MyApplication extends FASTElement {
 *     @Container container!: Container;
 *     connectedCallback() {
 *         this.container.register(Registration.singleton(LoginMapper, MyLoginMapper));
 *     }
 * }
 * ```
 *
 * @public
 */
export interface LoginMapper extends Mapper<LoginDTO, LoginEntity> {
}
/**
 * Default LoginMapper.
 * @public
 */
export declare class DefaultLoginMapper implements LoginMapper {
    protected uuid: UUID;
    /**
     * {@inheritDoc Mapper.toEntity}
     */
    toEntity: (dto: LoginDTO) => LoginEntity;
    /**
     * {@inheritDoc Mapper.toDTO}
     */
    toDTO: (entity: LoginEntity) => LoginDTO;
    protected fromSystemDTO: (system: DTOSystem) => EntitySystem;
    protected fromProductDTO: (products: DTOProduct[]) => EntityProduct[];
}
/**
 * LoginMapper DI key.
 *
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 *
 * @internal
 */
export declare const LoginMapper: import("@microsoft/fast-foundation").InterfaceSymbol<LoginMapper>;
//# sourceMappingURL=loginMapper.d.ts.map