import type { EVENT_LOGOUT_NACK, LOGOUT_ACK } from '../dto';
import type { LogoutAck, LogoutNack } from '../entity';
import { Mapper } from './types';
/**
 * LogoutDTO type.
 * @public
 */
export type LogoutDTO = LOGOUT_ACK | EVENT_LOGOUT_NACK;
/**
 * LogoutEntity type.
 * @public
 */
export type LogoutEntity = LogoutAck | LogoutNack;
/**
 * isLogoutAckDTO.
 * @param dto - Potential DTO.
 * @public
 */
export declare function isLogoutAckDTO(dto: LogoutDTO): dto is LOGOUT_ACK;
/**
 * isLogoutNackDTO.
 * @param dto - Potential DTO.
 * @public
 */
export declare function isLogoutNackDTO(dto: LogoutDTO): dto is EVENT_LOGOUT_NACK;
/**
 * isLogoutAckEntity.
 * @param entity - Potential entity.
 * @public
 */
export declare function isLogoutAckEntity(entity: LogoutEntity): entity is LogoutAck;
/**
 * isLogoutNackEntity.
 * @param entity - Potential entity.
 * @public
 */
export declare function isLogoutNackEntity(entity: LogoutEntity): entity is LogoutNack;
/**
 * LogoutMapper interface.
 *
 * @remarks
 * An extensible mapper for converting between logout DTOs and Entities, where you can normalise data, implement derived
 * fields, validation etc.
 *
 * @public
 */
export interface LogoutMapper extends Mapper<LogoutDTO, LogoutEntity> {
}
/**
 * Default LogoutMapper.
 * @public
 */
export declare class DefaultLogoutMapper implements LogoutMapper {
    /**
     * {@inheritDoc Mapper.toEntity}
     */
    toEntity: (dto: LogoutDTO) => LogoutEntity;
}
/**
 * LogoutMapper DI key.
 *
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 *
 * @internal
 */
export declare const LogoutMapper: import("@microsoft/fast-foundation").InterfaceSymbol<LogoutMapper>;
//# sourceMappingURL=logoutMapper.d.ts.map