import { UUID } from '@genesislcap/foundation-utils';
import type { EVENT_SELF_SERVICE_PASSWORD_RESET, EVENT_CHANGE_USER_PASSWORD, EVENT_PASSWORD_RESET_ACTION } from '../dto';
import type { ChangePasswordParams, ForgotPasswordParams, ResetPasswordParams } from '../machine';
import { Mapper } from './types';
/**
 * PasswordManagementDTO type.
 * @public
 */
export type PasswordManagementDTO = EVENT_SELF_SERVICE_PASSWORD_RESET | EVENT_CHANGE_USER_PASSWORD | EVENT_PASSWORD_RESET_ACTION;
/**
 * PasswordManagementEntity type.
 * @public
 */
export type PasswordManagementEntity = ForgotPasswordParams | ChangePasswordParams | ResetPasswordParams;
/**
 * PasswordManagementMapper interface.
 *
 * @remarks
 * A mapper for the self-service password management flows.
 *
 * @public
 */
export interface PasswordManagementMapper extends Mapper<PasswordManagementDTO, PasswordManagementEntity> {
}
/**
 * Default PasswordManagementMapper.
 * @public
 */
export declare class DefaultPasswordManagementMapper implements PasswordManagementMapper {
    protected uuid: UUID;
    /**
     * {@inheritDoc Mapper.toDTO}
     */
    toDTO: (entity: PasswordManagementEntity) => PasswordManagementDTO;
}
/**
 * PasswordManagementMapper DI key.
 *
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 *
 * @internal
 */
export declare const PasswordManagementMapper: import("@microsoft/fast-foundation").InterfaceSymbol<PasswordManagementMapper>;
//# sourceMappingURL=passwordManagementMapper.d.ts.map