import { CustomEventMap } from '@genesislcap/foundation-events';
import { AbstractStoreRoot, StoreRoot, StoreRootEventDetailMap } from '@genesislcap/foundation-store';
import type { AuthMachineEventMap, ChangePasswordParams, ForgotPasswordParams, LoginParams, ResetPasswordParams } from '../machine';
import { AuthMachine } from '../machine';
import { AuthConfig } from '../main';
import { AuthFormEntryStore } from './authFormEntry';
/**
 * @public
 */
export type AuthEventMap = StoreRootEventDetailMap & AuthMachineEventMap & {
    'auth-login': LoginParams;
    'auth-logout': void;
    'auth-change-password': ChangePasswordParams;
    'auth-forgot-password': ForgotPasswordParams;
    'auth-reset-password': ResetPasswordParams;
};
declare global {
    interface HTMLElementEventMap extends CustomEventMap<AuthEventMap> {
    }
}
type InternalAuthEventMap = {};
/**
 * AuthStore interface.
 * @remarks
 * This is the root store for the foundation-auth package.
 * @public
 */
export interface AuthStore extends StoreRoot {
    readonly isPending: boolean;
    readonly formEntry: AuthFormEntryStore;
    /**
     * Auth workflows and transient state (context in xstate lingo).
     */
    readonly authMachine: AuthMachine;
    /**
     * @param event - The machine mediation event.
     */
    onMachineEvent(event: CustomEvent<AuthEventMap['auth-machine-event']>): void;
    onLogin(event: CustomEvent<LoginParams>): void;
    onLogout(event: CustomEvent<void>): void;
    onChangePassword(event: CustomEvent<ChangePasswordParams>): void;
    onForgotPassword(event: CustomEvent<ForgotPasswordParams>): void;
    onResetPassword(event: CustomEvent<ResetPasswordParams>): void;
}
/**
 * Default implementation of the store.
 * @public
 */
export declare class DefaultAuthStore extends AbstractStoreRoot<AuthStore, AuthEventMap, InternalAuthEventMap> implements AuthStore {
    readonly config: AuthConfig;
    readonly authMachine: AuthMachine;
    readonly formEntry: AuthFormEntryStore;
    constructor(config: AuthConfig, authMachine: AuthMachine, formEntry: AuthFormEntryStore);
    get isPending(): boolean;
    onMachineEvent: EventListener;
    onLogin: EventListener;
    onLogout: EventListener;
    onChangePassword: EventListener;
    onForgotPassword: EventListener;
    onResetPassword: EventListener;
}
/**
 * DI key of the store.
 * @internal
 */
export declare const AuthStore: import("@microsoft/fast-foundation").InterfaceSymbol<import("@microsoft/fast-foundation").Key>;
export {};
//# sourceMappingURL=auth.d.ts.map