import { CustomEventMap } from '@genesislcap/foundation-events';
import { AbstractStore, Store } from '@genesislcap/foundation-store';
import { CredentialManager } from '../credential';
import { AuthConfig } from '../main';
import { IDP } from '../routes';
/**
 * @public
 */
export type AuthFormEntryEventMap = {
    'auth-autofill-form': void;
    'auth-organisation-changed': string;
    'auth-username-changed': string;
    'auth-email-changed': string;
    'auth-password-changed': string;
    'auth-password2-changed': string;
    'auth-showPasswords-changed': boolean;
};
declare global {
    interface HTMLElementEventMap extends CustomEventMap<AuthFormEntryEventMap> {
    }
}
type InternalEventMap = {};
/**
 * AuthFormEntryStore interface.
 * @public
 */
export interface AuthFormEntryStore extends Store {
    readonly host: string;
    readonly organisation: string;
    readonly username: string;
    readonly orgUsername: string;
    readonly email: string;
    readonly password: string;
    readonly password2: string;
    readonly showPasswords: boolean;
    readonly hasPasswordExpired: boolean;
    readonly passwordResetToken: string;
    readonly message: string;
    readonly hasErrors: boolean;
    readonly mfaCode: string;
    readonly idps: IDP[];
    readonly selectedIDP: string;
    readonly ssoToggled: boolean;
    readonly termsAgreed: boolean;
    onOrganisationChanged(event: CustomEvent<string>): void;
    onUsernameChanged(event: CustomEvent<string>): void;
    onEmailChanged(event: CustomEvent<string>): void;
    onPasswordChanged(event: CustomEvent<string>): void;
    onPassword2Changed(event: CustomEvent<string>): void;
    onShowPasswordsChanged(event: CustomEvent<boolean>): void;
    onAutofillForm(event: CustomEvent<void>): void;
}
/**
 * Default implementation of the store.
 * @public
 */
export declare class DefaultAuthFormEntryStore extends AbstractStore<AuthFormEntryStore, AuthFormEntryEventMap, InternalEventMap> implements AuthFormEntryStore {
    protected config: AuthConfig;
    protected credentialManager: CredentialManager;
    host: string;
    organisation: string;
    username: string;
    email: string;
    password: string;
    password2: string;
    showPasswords: boolean;
    hasPasswordExpired: boolean;
    passwordResetToken: string;
    message: string;
    hasErrors: boolean;
    mfaCode: string;
    idps: IDP[];
    selectedIDP: string;
    ssoToggled: boolean;
    termsAgreed: boolean;
    get orgUsername(): string;
    constructor();
    private autofill;
    onOrganisationChanged: EventListener;
    onUsernameChanged: EventListener;
    onEmailChanged: EventListener;
    onPasswordChanged: EventListener;
    onPassword2Changed: EventListener;
    onShowPasswordsChanged: EventListener;
    onAutofillForm: EventListener;
}
/**
 * DI key of the store.
 * @internal
 */
export declare const AuthFormEntryStore: import("@microsoft/fast-foundation").InterfaceSymbol<import("@microsoft/fast-foundation").Key>;
export {};
//# sourceMappingURL=authFormEntry.d.ts.map