import { __decorate } from "tslib";
import { DI } from '@microsoft/fast-foundation';
import { AuthConfig, getSubRoutePath } from '../main/config';
import { User } from '../user';
/**
 * Default LogoutUtility.
 *
 * @public
 */
export class DefaultLogoutUtility {
    /** {@inheritDoc LogoutUtility.run} */
    run() {
        if (this.user.isAuthenticated) {
            this.config.routeToUrl(getSubRoutePath('logout', this.config.hostPath));
        }
    }
}
__decorate([
    AuthConfig
], DefaultLogoutUtility.prototype, "config", void 0);
__decorate([
    User
], DefaultLogoutUtility.prototype, "user", void 0);
/**
 * LogoutUtility DI key.
 *
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 *
 * @internal
 */
export const LogoutUtility = DI.createInterface((x) => x.singleton(DefaultLogoutUtility));
/**
 * Gets LogoutUtility from the DI container.
 *
 * @remarks
 * A utility method for host applications that are not using decorators or the DI container.
 *
 * @example
 * ```ts
 * import { getLogoutUtility, LogoutUtility } from '@genesislcap/foundation-auth/logout';
 * ...
 * private logout: LogoutUtility = getLogoutUtility();
 * ...
 * this.logout.run();
 * ```
 *
 * @public
 */
export function getLogoutUtility() {
    return DI.getOrCreateDOMContainer().get(LogoutUtility);
}
