import { __awaiter, __decorate } from "tslib";
import { EventEmitter } from '@genesislcap/foundation-events';
import { customElement, FASTElement, observable } from '@microsoft/fast-element';
import { Container, inject, Registration } from '@microsoft/fast-foundation';
import { DefaultRouteRecognizer } from '@microsoft/fast-router';
import * as Components from '../components'; // < remove from hosted / non-develop version
import { MainRouterConfig } from '../routes';
import { AuthStore } from '../store';
import { definition, standaloneDefinition } from './main.definition';
/**
 * @public
 */
let Auth = class Auth extends EventEmitter(FASTElement) {
    constructor() {
        super(...arguments);
        /**
         * Marked true when remote components are loaded, currently unused.
         * @internal
         */
        this.ready = false;
    }
    /**
     * @internal
     */
    connectedCallback() {
        const _super = Object.create(null, {
            connectedCallback: { get: () => super.connectedCallback }
        });
        return __awaiter(this, void 0, void 0, function* () {
            this.registerDIDependencies();
            _super.connectedCallback.call(this);
            this.addEventListeners();
            yield this.registerCommonComponents();
            this.readyStore();
        });
    }
    /**
     * @internal
     */
    disconnectedCallback() {
        super.disconnectedCallback();
        this.removeEventListeners();
    }
    /**
     * Called from the connectedCallback
     * @internal
     */
    registerCommonComponents() {
        return __awaiter(this, void 0, void 0, function* () {
            /**
             * Send event to indicate some async work is happening. Will be picked up by overlay micro frontend.
             */
            yield Components.loadRemotes({});
            /**
             * Simulate loading delay, TODO: Remove
             *
             * await new Promise(resolve => setTimeout(resolve, 3000));
             */
            this.ready = true; // < machine not pending?
        });
    }
    /**
     * @internal
     */
    registerDIDependencies() {
        this.container.register(Registration.transient(DefaultRouteRecognizer, DefaultRouteRecognizer));
    }
    /**
     * @internal
     */
    addEventListeners() {
        this.addEventListener('store-connected', this.store.onConnected);
    }
    /**
     * @internal
     */
    removeEventListeners() {
        this.removeEventListener('store-connected', this.store.onConnected);
    }
    /**
     * @internal
     */
    readyStore() {
        this.$emit('store-connected', this);
        this.$emit('store-ready', true);
    }
};
__decorate([
    AuthStore
], Auth.prototype, "store", void 0);
__decorate([
    inject(MainRouterConfig)
], Auth.prototype, "config", void 0);
__decorate([
    Container
], Auth.prototype, "container", void 0);
__decorate([
    observable
], Auth.prototype, "ready", void 0);
__decorate([
    observable
], Auth.prototype, "provider", void 0);
Auth = __decorate([
    customElement(standaloneDefinition)
], Auth);
export { Auth };
/**
 * @beta
 * @privateRemarks
 * A hosted version of the MF that doesn't set up a design system or components. This is what apps would use to truly
 * customise the MF for their needs via define.ts.
 */
let AuthHosted = class AuthHosted extends Auth {
    registerCommonComponents() {
        return __awaiter(this, void 0, void 0, function* () {
            this.ready = true;
        });
    }
};
AuthHosted = __decorate([
    customElement(Object.assign(Object.assign({}, definition), { name: `${definition.name}-hosted` }))
], AuthHosted);
export { AuthHosted };
