import { DI } from '@microsoft/fast-foundation';
import { MESSAGE_TYPE } from '../dto';
import { logger } from '../utils';
import { MappingError } from './error';
import { fromDTOAck, fromDTONack } from './utils';
/**
 * isLogoutAckDTO.
 * @param dto - Potential DTO.
 * @public
 */
export function isLogoutAckDTO(dto) {
    return (dto === null || dto === void 0 ? void 0 : dto.MESSAGE_TYPE) === MESSAGE_TYPE.LOGOUT_ACK;
}
/**
 * isLogoutNackDTO.
 * @param dto - Potential DTO.
 * @public
 */
export function isLogoutNackDTO(dto) {
    return (dto === null || dto === void 0 ? void 0 : dto.MESSAGE_TYPE) === MESSAGE_TYPE.LOGOUT_NACK;
}
/**
 * isLogoutAckEntity.
 * @param entity - Potential entity.
 * @public
 */
export function isLogoutAckEntity(entity) {
    return (entity === null || entity === void 0 ? void 0 : entity.messageType) === MESSAGE_TYPE.LOGOUT_ACK;
}
/**
 * isLogoutNackEntity.
 * @param entity - Potential entity.
 * @public
 */
export function isLogoutNackEntity(entity) {
    return (entity === null || entity === void 0 ? void 0 : entity.messageType) === MESSAGE_TYPE.LOGOUT_NACK;
}
/**
 * Default LogoutMapper.
 * @public
 */
export class DefaultLogoutMapper {
    constructor() {
        /**
         * {@inheritDoc Mapper.toEntity}
         */
        this.toEntity = (dto) => {
            try {
                if (isLogoutNackDTO(dto)) {
                    return fromDTONack(dto);
                }
                if (isLogoutAckDTO(dto)) {
                    const ack = Object.assign(Object.assign({}, fromDTOAck(dto)), { oidcLogoutUrl: dto.OIDC_LOGOUT_URL });
                    return ack;
                }
                throw new Error('No Entity mapping implementation for provided DTO');
            }
            catch (e) {
                logger.error(e);
                throw new MappingError(dto);
            }
        };
    }
}
/**
 * LogoutMapper DI key.
 *
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 *
 * @internal
 */
export const LogoutMapper = DI.createInterface((x) => x.singleton(DefaultLogoutMapper));
