import { __decorate } from "tslib";
import { observable } from '@microsoft/fast-element';
/**
 * @public
 */
export class DefaultMessageMapper {
    constructor() {
        this.map = new Map();
    }
    /** {@inheritDoc MessageMapper.set} */
    set(key, mapper) {
        this.map = new Map(this.map.set(key, mapper));
    }
    /**
     * Get a mapper by message type.
     * @param key - The message type as key.
     * @returns The mapper if it exists, otherwise undefined.
     * @public
     */
    get(key) {
        return this.map.get(key);
    }
    /**
     * Has a mapper for key.
     * @param key - The message type as key.
     * @returns True if it exists, otherwise false.
     *
     * @public
     */
    has(key) {
        return this.map.has(key);
    }
    /**
     * Delete a mapper.
     * @param key - The message type as key.
     * @returns True if successful, otherwise false.
     *
     * @public
     */
    delete(key) {
        const result = this.map.delete(key);
        if (result) {
            this.map = new Map(this.map);
        }
        return result;
    }
    /**
     * Clear mappers.
     * @public
     */
    clear() {
        this.map = new Map();
    }
    /**
     * The size of the mapper map.
     * @returns number
     *
     * @public
     */
    get size() {
        return this.map.size;
    }
}
__decorate([
    observable
], DefaultMessageMapper.prototype, "map", void 0);
/**
 * A factory to create a MessageMapper.
 * @returns A MessageMapper instance.
 *
 * @public
 */
export const createMessageMapper = () => new DefaultMessageMapper();
