import { __decorate, __param } from "tslib";
import { DI } from '@microsoft/fast-foundation';
import { MESSAGE_TYPE } from '../dto';
import { LoginMapper } from './loginMapper';
import { LogoutMapper } from './logoutMapper';
import { DefaultMessageMapper } from './map';
import { PasswordManagementMapper } from './passwordManagementMapper';
/**
 * Default AuthMessageMapper.
 * @public
 */
let DefaultAuthMessageMapper = class DefaultAuthMessageMapper extends DefaultMessageMapper {
    constructor(loginMapper, logoutMapper, passwordMapper) {
        super();
        this.loginMapper = loginMapper;
        this.logoutMapper = logoutMapper;
        this.passwordMapper = passwordMapper;
        /**
         * Login
         */
        this.set(MESSAGE_TYPE.LOGIN, loginMapper);
        this.set(MESSAGE_TYPE.LOGIN_ACK, loginMapper);
        this.set(MESSAGE_TYPE.LOGIN_NACK, loginMapper);
        this.set(MESSAGE_TYPE.LOGIN_DETAILS_ACK, loginMapper);
        this.set(MESSAGE_TYPE.LOGIN_DETAILS_NACK, loginMapper);
        /**
         * Logout
         */
        this.set(MESSAGE_TYPE.LOGOUT_ACK, logoutMapper);
        this.set(MESSAGE_TYPE.LOGOUT_NACK, logoutMapper);
        /**
         * Password management
         */
        this.set(MESSAGE_TYPE.FORGOT_PASSWORD, passwordMapper);
        this.set(MESSAGE_TYPE.CHANGE_PASSWORD, passwordMapper);
        this.set(MESSAGE_TYPE.RESET_PASSWORD, passwordMapper);
    }
};
DefaultAuthMessageMapper = __decorate([
    __param(0, LoginMapper),
    __param(1, LogoutMapper),
    __param(2, PasswordManagementMapper)
], DefaultAuthMessageMapper);
export { DefaultAuthMessageMapper };
/**
 * AuthMessageMapper DI key.
 *
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 *
 * @internal
 */
export const AuthMessageMapper = DI.createInterface((x) => x.singleton(DefaultAuthMessageMapper));
