import { MESSAGE_TYPE } from '../dto';
/**
 * @public
 */
export const fromDTOStringArray = (arr) => Array.isArray(arr) ? arr.map((v) => (v !== null && v !== void 0 ? v : '').toLowerCase()) : [];
/**
 * @public
 */
export const fromDTONackErrorWarningArray = (arr) => Array.isArray(arr)
    ? arr.map((v) => ({
        type: v['@type'],
        code: v.CODE,
        statusCode: v.STATUS_CODE,
        text: v.TEXT,
    }))
    : [];
/**
 * includesErrorWarningCode
 * @public
 */
export const includesErrorWarningCode = (arr, code) => Array.isArray(arr) ? arr.some((e) => e.CODE === code || e.STATUS_CODE === code) : false;
/**
 * hasDTOErrorWarningCode
 * @remarks
 * Checks both the `CODE` and `STATUS_CODE` values for a match.
 * @param dto - NACK.
 * @param code - The error or warning code.
 * @public
 */
export const hasDTOErrorWarningCode = (dto, code) => {
    const errorMatch = includesErrorWarningCode(dto.ERROR, code);
    const warningMatch = includesErrorWarningCode(dto.WARNING, code);
    return errorMatch || warningMatch;
};
/**
 * fromDTOAck
 * @param dto - ACK.
 * @public
 */
export const fromDTOAck = (dto) => ({
    messageType: dto.MESSAGE_TYPE,
    sourceRef: dto.SOURCE_REF,
});
/**
 * fromDTONack
 * @param dto - NACK.
 * @public
 */
export const fromDTONack = (dto) => ({
    messageType: dto.MESSAGE_TYPE,
    sourceRef: dto.SOURCE_REF,
    error: fromDTONackErrorWarningArray(dto.ERROR),
    warning: fromDTONackErrorWarningArray(dto.WARNING),
});
/**
 * isDTONack.
 * @param dto - Potential NACK.
 * @public
 */
export function isNackDTO(dto) {
    return (dto === null || dto === void 0 ? void 0 : dto.MESSAGE_TYPE) === MESSAGE_TYPE.EVENT_NACK;
}
/**
 * createHTTPHeadersFromDTO.
 * @param dto - DTO being sent to the server.
 * @param contentType - Optional content-type, defaults to `application/json; charset=UTF-8`.
 * @public
 */
export function createHTTPHeadersFromDTO(dto, contentType = 'application/json; charset=UTF-8') {
    const headers = { 'Content-type': contentType };
    if (dto.SOURCE_REF) {
        headers['source-ref'] = dto.SOURCE_REF;
        headers['SOURCE_REF'] = dto.SOURCE_REF;
    }
    if (dto.USER_NAME) {
        headers['user-name'] = dto.USER_NAME;
        headers['USER_NAME'] = dto.USER_NAME;
    }
    return headers;
}
