import { sync } from '@genesislcap/foundation-utils';
import { html, repeat, when } from '@microsoft/fast-element';
import { organisationField, passwordField, showPasswordsCheckbox, usernameField, submitButton, } from '../base';
const regularLogin = html `
  ${when((login) => !login.store.formEntry.ssoToggled, html `
      ${organisationField()} ${usernameField()} ${passwordField()}
      <span class="case-warning">*Fields are case-sensitive</span>
      ${showPasswordsCheckbox()}
      <div class="form-buttons">
        ${(x) => submitButton('Login', 'submit-login', x.submitDisabled)}
        <div class="links">
          <div class="password-links">
            ${when((x) => !x.config.omitRoutes.includes('forgot-password'), html `
                <a
                  class="link-url"
                  @click=${(x) => x.onNavigate(x.getSubRoutePath(`forgot-password`))}
                  data-test-id="forgot-password"
                >
                  Forgot Password?
                </a>
              `)}
            ${when((x) => !x.config.omitRoutes.includes('reset-password'), html `
                <a
                  class="link-url"
                  @click=${(x) => x.onNavigate(x.getSubRoutePath(`reset-password`))}
                  data-test-id="reset-password"
                >
                  Change Password
                </a>
              `)}
          </div>
          <div class="account-links">
            ${when((x) => !x.config.omitRoutes.includes('request-account'), html `
                <a
                  class="link-url"
                  @click=${(x) => x.onNavigate(x.getSubRoutePath(`request-account`))}
                  data-test-id="request-account"
                >
                  Request Account
                </a>
              `)}
          </div>
        </div>
      </div>
      ${when((x) => x.config.versionInformation, html `
          <div>
            <span class="version" data-test-id="version">
              ${(x) => x.config.versionInformation}
            </span>
          </div>
        `)}
    `)}
`;
const ssoLogin = html `
  ${when((login) => login.store.formEntry.ssoToggled, html `
      <div class="sso">
        <span class="form-title">Providers</span>
        <zero-select
          name="sso"
          data-test-id="sso"
          :value=${sync((x) => x.selectedIDP)}
          ?disabled=${(x) => !x.idps.length}
        >
          ${repeat((x) => x.idps, html `
              <zero-option value="${({ id }) => id}">${({ id }) => id}</zero-option>
            `)}
        </zero-select>
        <zero-button
          type="button"
          class="action-btn"
          appearance="primary-gradient"
          @click="${(x) => x.onClickSSO()}"
          data-test-id="sso-login"
          ?disabled=${(x) => !x.selectedIDP}
        >
          SSO Login
        </zero-button>
      </div>
    `)}
`;
export const LoginTemplate = html `
  <auth-background>
    <div class="container">
      <zero-card class="card-pd">
        <div class="column-content">
          <auth-logo></auth-logo>
          <div class="heading2">Login</div>
        </div>
        <form
          id="auth-login"
          method="post"
          autocomplete="on"
          @submit=${(x) => x.onLoginSubmit()}
          ?disabled=${(x) => x.submitDisabled}
          data-test-id="auth-login"
        >
          ${regularLogin} ${ssoLogin}
          ${when((x) => x.config.sso, html `
              <zero-checkbox
                ?checked="${sync((x) => x.store.formEntry.ssoToggled, 'boolean')}"
                name="sso-toggle"
                data-test-id="sso-toggle"
              >
                ${(x) => x.store.formEntry.ssoToggled ? 'SSO Enabled' + x.selectedIDPName : 'Enable SSO?'}
              </zero-checkbox>
            `)}
          <auth-message></auth-message>
        </form>
      </zero-card>
    </div>
  </auth-background>
`;
