import { __awaiter, __decorate } from "tslib";
import { customElement, observable, volatile } from '@microsoft/fast-element';
import { commonStyles } from '../../styles';
import { BaseRoute } from '../base';
import { ResetPasswordTemplate as template } from './reset-password.template';
let ResetPassword = class ResetPassword extends BaseRoute {
    constructor() {
        super(...arguments);
        this.hasPasswordExpired = false;
        this.passwordResetToken = '';
    }
    enter(phase) {
        return __awaiter(this, void 0, void 0, function* () {
            this.hasPasswordExpired = !!phase.route.queryParams.expired;
            this.passwordResetToken = phase.route.queryParams.password;
        });
    }
    onSubmit() {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.passwordResetToken) {
                this.$emit('auth-reset-password', {
                    username: this.store.formEntry.orgUsername,
                    newPassword: this.store.formEntry.password2,
                    resetToken: this.passwordResetToken,
                });
                return;
            }
            this.$emit('auth-change-password', {
                username: this.store.formEntry.orgUsername,
                oldPassword: this.store.formEntry.password,
                newPassword: this.store.formEntry.password2,
            });
        });
    }
    get headingText() {
        return this.hasPasswordExpired ? 'You are required to change your password' : 'Change Password';
    }
};
__decorate([
    observable
], ResetPassword.prototype, "hasPasswordExpired", void 0);
__decorate([
    observable
], ResetPassword.prototype, "passwordResetToken", void 0);
__decorate([
    volatile
], ResetPassword.prototype, "headingText", null);
ResetPassword = __decorate([
    customElement({
        name: 'foundation-auth-reset-password',
        template,
        styles: commonStyles,
    })
], ResetPassword);
export { ResetPassword };
