import { __decorate, __param } from "tslib";
import { AbstractStoreRoot, registerStore, } from '@genesislcap/foundation-store';
import { AuthMachine } from '../machine';
import { AuthConfig } from '../main';
import { AuthFormEntryStore } from './authFormEntry';
/**
 * Default implementation of the store.
 * @public
 */
let DefaultAuthStore = class DefaultAuthStore extends AbstractStoreRoot {
    constructor(config, authMachine, formEntry) {
        super(formEntry);
        this.config = config;
        this.authMachine = authMachine;
        this.formEntry = formEntry;
        this.onMachineEvent = this.createListener('auth-machine-event', (event) => this.authMachine.send(event));
        this.onLogin = this.createListener('auth-login', (params) => this.authMachine.send({
            type: 'login',
            params,
        }));
        this.onLogout = this.createListener('auth-logout', () => this.authMachine.send({ type: 'logout' }));
        this.onChangePassword = this.createListener('auth-change-password', (params) => this.authMachine.send({
            type: 'change-password',
            params,
        }));
        this.onForgotPassword = this.createListener('auth-forgot-password', (params) => this.authMachine.send({
            type: 'forgot-password',
            params,
        }));
        this.onResetPassword = this.createListener('auth-reset-password', (params) => this.authMachine.send({
            type: 'reset-password',
            params,
        }));
    }
    get isPending() {
        return this.authMachine.hasTag('pending');
    }
};
DefaultAuthStore = __decorate([
    __param(0, AuthConfig),
    __param(1, AuthMachine),
    __param(2, AuthFormEntryStore)
], DefaultAuthStore);
export { DefaultAuthStore };
/**
 * DI key of the store.
 * @internal
 */
export const AuthStore = registerStore(DefaultAuthStore, 'AuthStore');
