/// <reference types="webappsec-credential-management" />

import { AbstractMachine } from '@genesislcap/foundation-state-machine';
import { AbstractStore } from '@genesislcap/foundation-store';
import { AbstractStoreRoot } from '@genesislcap/foundation-store';
import { Binding } from '@microsoft/fast-element';
import { Constructable } from '@microsoft/fast-element';
import { Container } from '@microsoft/fast-foundation';
import { Controller } from '@microsoft/fast-element';
import { DefineFunction } from '@genesislcap/foundation-ui';
import type { DoneInvokeEvent } from 'xstate';
import { ElementStyles } from '@microsoft/fast-element';
import { EmitOptions } from '@genesislcap/foundation-events';
import { EmitReturn } from '@genesislcap/foundation-events';
import type { ErrorEvent as ErrorEvent_2 } from 'xstate';
import { FetchMachine } from '@genesislcap/foundation-state-machine';
import { FetchMachineEvent } from '@genesislcap/foundation-state-machine';
import { InterfaceSymbol } from '@microsoft/fast-foundation';
import type { InterpreterOptions } from 'xstate';
import { Key } from '@microsoft/fast-foundation';
import { KeysMatching } from '@genesislcap/foundation-events';
import { Listener } from '@genesislcap/foundation-utils';
import { Logger } from '@genesislcap/foundation-utils';
import { Machine } from '@genesislcap/foundation-state-machine';
import type { MachineContext } from '@genesislcap/foundation-state-machine';
import { Observer } from '@genesislcap/foundation-utils';
import { PartialFASTElementDefinition } from '@microsoft/fast-element';
import { RouterConfiguration } from '@microsoft/fast-router';
import { Store } from '@genesislcap/foundation-store';
import { StoreRoot } from '@genesislcap/foundation-store';
import { StoreRootEventDetailMap } from '@genesislcap/foundation-store';
import { SyntheticViewTemplate } from '@microsoft/fast-element';
import { TemplateElementDependency } from '@genesislcap/foundation-ui';
import { UUID } from '@genesislcap/foundation-utils';
import { ViewTemplate } from '@microsoft/fast-element';

/**
 * @internal
 */
export declare interface ACK extends MESSAGE {
}

/**
 * @internal
 */
export declare interface Ack extends Message {
}

/**
 * @public
 */
export declare class Auth extends Auth_base {
    /**
     * @internal
     */
    store: AuthStore;
    /**
     * Configuration for the routes and their associated settings.
     * The client would override this in their app with their own settings to set
     * their routes up as desired
     * @internal
     */
    config: MainRouterConfig;
    /**
     * The DI container used to register required components in {@link Auth.registerDIDependencies}
     * @internal
     */
    container: Container;
    /**
     * Marked true when remote components are loaded, currently unused.
     * @internal
     */
    ready: boolean;
    /**
     * DS provider / root level template.
     * @internal
     */
    provider: HTMLElement;
    /**
     * @internal
     */
    connectedCallback(): Promise<void>;
    /**
     * @internal
     */
    disconnectedCallback(): void;
    /**
     * Called from the connectedCallback
     * @internal
     */
    registerCommonComponents(): Promise<void>;
    /**
     * @internal
     */
    protected registerDIDependencies(): void;
    /**
     * @internal
     */
    protected addEventListeners(): void;
    /**
     * @internal
     */
    protected removeEventListeners(): void;
    /**
     * @internal
     */
    protected readyStore(): void;
}

declare const Auth_base: abstract new (...args: any[]) => {
    $emit<K extends "store-connected" | "store-disconnected" | "store-ready" | "auth-machine-event" | "auth-login" | "auth-logout" | "auth-change-password" | "auth-forgot-password" | "auth-reset-password">(...args: AuthEventMap[K] extends void ? [type: K, options?: EmitOptions] : [type: K, detail: AuthEventMap[K], options?: EmitOptions]): EmitReturn;
    accessKey: string;
    readonly accessKeyLabel: string;
    autocapitalize: string;
    dir: string;
    draggable: boolean;
    hidden: boolean;
    inert: boolean;
    innerText: string;
    lang: string;
    readonly offsetHeight: number;
    readonly offsetLeft: number;
    readonly offsetParent: Element;
    readonly offsetTop: number;
    readonly offsetWidth: number;
    outerText: string;
    spellcheck: boolean;
    title: string;
    translate: boolean;
    attachInternals(): ElementInternals;
    click(): void;
    addEventListener<K_1 extends keyof HTMLElementEventMap>(type: K_1, listener: (this: HTMLElement, ev: HTMLElementEventMap[K_1]) => any, options?: boolean | AddEventListenerOptions): void;
    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;
    removeEventListener<K_2 extends keyof HTMLElementEventMap>(type: K_2, listener: (this: HTMLElement, ev: HTMLElementEventMap[K_2]) => any, options?: boolean | EventListenerOptions): void;
    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;
    readonly attributes: NamedNodeMap;
    readonly classList: DOMTokenList;
    className: string;
    readonly clientHeight: number;
    readonly clientLeft: number;
    readonly clientTop: number;
    readonly clientWidth: number;
    id: string;
    readonly localName: string;
    readonly namespaceURI: string;
    onfullscreenchange: (this: Element, ev: Event) => any;
    onfullscreenerror: (this: Element, ev: Event) => any;
    outerHTML: string;
    readonly ownerDocument: Document;
    readonly part: DOMTokenList;
    readonly prefix: string;
    readonly scrollHeight: number;
    scrollLeft: number;
    scrollTop: number;
    readonly scrollWidth: number;
    readonly shadowRoot: ShadowRoot;
    slot: string;
    readonly tagName: string;
    attachShadow(init: ShadowRootInit): ShadowRoot;
    closest<K_3 extends keyof HTMLElementTagNameMap>(selector: K_3): HTMLElementTagNameMap[K_3];
    closest<K_4 extends keyof SVGElementTagNameMap>(selector: K_4): SVGElementTagNameMap[K_4];
    closest<E extends Element = Element>(selectors: string): E;
    getAttribute(qualifiedName: string): string;
    getAttributeNS(namespace: string, localName: string): string;
    getAttributeNames(): string[];
    getAttributeNode(qualifiedName: string): Attr;
    getAttributeNodeNS(namespace: string, localName: string): Attr;
    getBoundingClientRect(): DOMRect;
    getClientRects(): DOMRectList;
    getElementsByClassName(classNames: string): HTMLCollectionOf<Element>;
    getElementsByTagName<K_5 extends keyof HTMLElementTagNameMap>(qualifiedName: K_5): HTMLCollectionOf<HTMLElementTagNameMap[K_5]>;
    getElementsByTagName<K_6 extends keyof SVGElementTagNameMap>(qualifiedName: K_6): HTMLCollectionOf<SVGElementTagNameMap[K_6]>;
    getElementsByTagName(qualifiedName: string): HTMLCollectionOf<Element>;
    getElementsByTagNameNS(namespaceURI: "http://www.w3.org/1999/xhtml", localName: string): HTMLCollectionOf<HTMLElement>;
    getElementsByTagNameNS(namespaceURI: "http://www.w3.org/2000/svg", localName: string): HTMLCollectionOf<SVGElement>;
    getElementsByTagNameNS(namespace: string, localName: string): HTMLCollectionOf<Element>;
    hasAttribute(qualifiedName: string): boolean;
    hasAttributeNS(namespace: string, localName: string): boolean;
    hasAttributes(): boolean;
    hasPointerCapture(pointerId: number): boolean;
    insertAdjacentElement(where: InsertPosition, element: Element): Element;
    insertAdjacentHTML(position: InsertPosition, text: string): void;
    insertAdjacentText(where: InsertPosition, data: string): void;
    matches(selectors: string): boolean;
    releasePointerCapture(pointerId: number): void;
    removeAttribute(qualifiedName: string): void;
    removeAttributeNS(namespace: string, localName: string): void;
    removeAttributeNode(attr: Attr): Attr;
    requestFullscreen(options?: FullscreenOptions): Promise<void>;
    requestPointerLock(): void;
    scroll(options?: ScrollToOptions): void;
    scroll(x: number, y: number): void;
    scrollBy(options?: ScrollToOptions): void;
    scrollBy(x: number, y: number): void;
    scrollIntoView(arg?: boolean | ScrollIntoViewOptions): void;
    scrollTo(options?: ScrollToOptions): void;
    scrollTo(x: number, y: number): void;
    setAttribute(qualifiedName: string, value: string): void;
    setAttributeNS(namespace: string, qualifiedName: string, value: string): void;
    setAttributeNode(attr: Attr): Attr;
    setAttributeNodeNS(attr: Attr): Attr;
    setPointerCapture(pointerId: number): void;
    toggleAttribute(qualifiedName: string, force?: boolean): boolean;
    webkitMatchesSelector(selectors: string): boolean;
    readonly baseURI: string;
    readonly childNodes: NodeListOf<ChildNode>;
    readonly firstChild: ChildNode;
    readonly isConnected: boolean;
    readonly lastChild: ChildNode;
    readonly nextSibling: ChildNode;
    readonly nodeName: string;
    readonly nodeType: number;
    nodeValue: string;
    readonly parentElement: HTMLElement;
    readonly parentNode: ParentNode;
    readonly previousSibling: ChildNode;
    textContent: string;
    appendChild<T extends Node>(node: T): T;
    cloneNode(deep?: boolean): Node;
    compareDocumentPosition(other: Node): number;
    contains(other: Node): boolean;
    getRootNode(options?: GetRootNodeOptions): Node;
    hasChildNodes(): boolean;
    insertBefore<T_1 extends Node>(node: T_1, child: Node): T_1;
    isDefaultNamespace(namespace: string): boolean;
    isEqualNode(otherNode: Node): boolean;
    isSameNode(otherNode: Node): boolean;
    lookupNamespaceURI(prefix: string): string;
    lookupPrefix(namespace: string): string;
    normalize(): void;
    removeChild<T_2 extends Node>(child: T_2): T_2;
    replaceChild<T_3 extends Node>(node: Node, child: T_3): T_3;
    readonly ATTRIBUTE_NODE: number;
    readonly CDATA_SECTION_NODE: number;
    readonly COMMENT_NODE: number;
    readonly DOCUMENT_FRAGMENT_NODE: number;
    readonly DOCUMENT_NODE: number;
    readonly DOCUMENT_POSITION_CONTAINED_BY: number;
    readonly DOCUMENT_POSITION_CONTAINS: number;
    readonly DOCUMENT_POSITION_DISCONNECTED: number;
    readonly DOCUMENT_POSITION_FOLLOWING: number;
    readonly DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC: number;
    readonly DOCUMENT_POSITION_PRECEDING: number;
    readonly DOCUMENT_TYPE_NODE: number;
    readonly ELEMENT_NODE: number;
    readonly ENTITY_NODE: number;
    readonly ENTITY_REFERENCE_NODE: number;
    readonly NOTATION_NODE: number;
    readonly PROCESSING_INSTRUCTION_NODE: number;
    readonly TEXT_NODE: number;
    dispatchEvent(event: Event): boolean;
    ariaAtomic: string;
    ariaAutoComplete: string;
    ariaBusy: string;
    ariaChecked: string;
    ariaColCount: string;
    ariaColIndex: string;
    ariaColIndexText: string;
    ariaColSpan: string;
    ariaCurrent: string;
    ariaDisabled: string;
    ariaExpanded: string;
    ariaHasPopup: string;
    ariaHidden: string;
    ariaInvalid: string;
    ariaKeyShortcuts: string;
    ariaLabel: string;
    ariaLevel: string;
    ariaLive: string;
    ariaModal: string;
    ariaMultiLine: string;
    ariaMultiSelectable: string;
    ariaOrientation: string;
    ariaPlaceholder: string;
    ariaPosInSet: string;
    ariaPressed: string;
    ariaReadOnly: string;
    ariaRequired: string;
    ariaRoleDescription: string;
    ariaRowCount: string;
    ariaRowIndex: string;
    ariaRowIndexText: string;
    ariaRowSpan: string;
    ariaSelected: string;
    ariaSetSize: string;
    ariaSort: string;
    ariaValueMax: string;
    ariaValueMin: string;
    ariaValueNow: string;
    ariaValueText: string;
    role: string;
    animate(keyframes: PropertyIndexedKeyframes | Keyframe[], options?: number | KeyframeAnimationOptions): Animation;
    getAnimations(options?: GetAnimationsOptions): Animation[];
    after(...nodes: (string | Node)[]): void;
    before(...nodes: (string | Node)[]): void;
    remove(): void;
    replaceWith(...nodes: (string | Node)[]): void;
    innerHTML: string;
    readonly nextElementSibling: Element;
    readonly previousElementSibling: Element;
    readonly childElementCount: number;
    readonly children: HTMLCollection;
    readonly firstElementChild: Element;
    readonly lastElementChild: Element;
    append(...nodes: (string | Node)[]): void;
    prepend(...nodes: (string | Node)[]): void;
    querySelector<K_7 extends keyof HTMLElementTagNameMap>(selectors: K_7): HTMLElementTagNameMap[K_7];
    querySelector<K_8 extends keyof SVGElementTagNameMap>(selectors: K_8): SVGElementTagNameMap[K_8];
    querySelector<E_1 extends Element = Element>(selectors: string): E_1;
    querySelectorAll<K_9 extends keyof HTMLElementTagNameMap>(selectors: K_9): NodeListOf<HTMLElementTagNameMap[K_9]>;
    querySelectorAll<K_10 extends keyof SVGElementTagNameMap>(selectors: K_10): NodeListOf<SVGElementTagNameMap[K_10]>;
    querySelectorAll<E_2 extends Element = Element>(selectors: string): NodeListOf<E_2>;
    replaceChildren(...nodes: (string | Node)[]): void;
    readonly assignedSlot: HTMLSlotElement;
    oncopy: (this: DocumentAndElementEventHandlers, ev: ClipboardEvent) => any;
    oncut: (this: DocumentAndElementEventHandlers, ev: ClipboardEvent) => any;
    onpaste: (this: DocumentAndElementEventHandlers, ev: ClipboardEvent) => any;
    readonly style: CSSStyleDeclaration;
    contentEditable: string;
    enterKeyHint: string;
    inputMode: string;
    readonly isContentEditable: boolean;
    onabort: (this: GlobalEventHandlers, ev: UIEvent) => any;
    onanimationcancel: (this: GlobalEventHandlers, ev: AnimationEvent) => any;
    onanimationend: (this: GlobalEventHandlers, ev: AnimationEvent) => any;
    onanimationiteration: (this: GlobalEventHandlers, ev: AnimationEvent) => any;
    onanimationstart: (this: GlobalEventHandlers, ev: AnimationEvent) => any;
    onauxclick: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onbeforeinput: (this: GlobalEventHandlers, ev: InputEvent) => any;
    onblur: (this: GlobalEventHandlers, ev: FocusEvent) => any;
    oncancel: (this: GlobalEventHandlers, ev: Event) => any;
    oncanplay: (this: GlobalEventHandlers, ev: Event) => any;
    oncanplaythrough: (this: GlobalEventHandlers, ev: Event) => any;
    onchange: (this: GlobalEventHandlers, ev: Event) => any;
    onclick: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onclose: (this: GlobalEventHandlers, ev: Event) => any;
    oncontextmenu: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    oncuechange: (this: GlobalEventHandlers, ev: Event) => any;
    ondblclick: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    ondrag: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondragend: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondragenter: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondragleave: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondragover: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondragstart: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondrop: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondurationchange: (this: GlobalEventHandlers, ev: Event) => any;
    onemptied: (this: GlobalEventHandlers, ev: Event) => any;
    onended: (this: GlobalEventHandlers, ev: Event) => any;
    onerror: OnErrorEventHandlerNonNull;
    onfocus: (this: GlobalEventHandlers, ev: FocusEvent) => any;
    onformdata: (this: GlobalEventHandlers, ev: FormDataEvent) => any;
    ongotpointercapture: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    oninput: (this: GlobalEventHandlers, ev: Event) => any;
    oninvalid: (this: GlobalEventHandlers, ev: Event) => any;
    onkeydown: (this: GlobalEventHandlers, ev: KeyboardEvent) => any;
    onkeypress: (this: GlobalEventHandlers, ev: KeyboardEvent) => any;
    onkeyup: (this: GlobalEventHandlers, ev: KeyboardEvent) => any;
    onload: (this: GlobalEventHandlers, ev: Event) => any;
    onloadeddata: (this: GlobalEventHandlers, ev: Event) => any;
    onloadedmetadata: (this: GlobalEventHandlers, ev: Event) => any;
    onloadstart: (this: GlobalEventHandlers, ev: Event) => any;
    onlostpointercapture: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onmousedown: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onmouseenter: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onmouseleave: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onmousemove: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onmouseout: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onmouseover: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onmouseup: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onpause: (this: GlobalEventHandlers, ev: Event) => any;
    onplay: (this: GlobalEventHandlers, ev: Event) => any;
    onplaying: (this: GlobalEventHandlers, ev: Event) => any;
    onpointercancel: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointerdown: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointerenter: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointerleave: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointermove: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointerout: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointerover: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointerup: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onprogress: (this: GlobalEventHandlers, ev: ProgressEvent<EventTarget>) => any;
    onratechange: (this: GlobalEventHandlers, ev: Event) => any;
    onreset: (this: GlobalEventHandlers, ev: Event) => any;
    onresize: (this: GlobalEventHandlers, ev: UIEvent) => any;
    onscroll: (this: GlobalEventHandlers, ev: Event) => any;
    onsecuritypolicyviolation: (this: GlobalEventHandlers, ev: SecurityPolicyViolationEvent) => any;
    onseeked: (this: GlobalEventHandlers, ev: Event) => any;
    onseeking: (this: GlobalEventHandlers, ev: Event) => any;
    onselect: (this: GlobalEventHandlers, ev: Event) => any;
    onselectionchange: (this: GlobalEventHandlers, ev: Event) => any;
    onselectstart: (this: GlobalEventHandlers, ev: Event) => any;
    onslotchange: (this: GlobalEventHandlers, ev: Event) => any;
    onstalled: (this: GlobalEventHandlers, ev: Event) => any;
    onsubmit: (this: GlobalEventHandlers, ev: SubmitEvent) => any;
    onsuspend: (this: GlobalEventHandlers, ev: Event) => any;
    ontimeupdate: (this: GlobalEventHandlers, ev: Event) => any;
    ontoggle: (this: GlobalEventHandlers, ev: Event) => any;
    ontouchcancel?: (this: GlobalEventHandlers, ev: TouchEvent) => any;
    ontouchend?: (this: GlobalEventHandlers, ev: TouchEvent) => any;
    ontouchmove?: (this: GlobalEventHandlers, ev: TouchEvent) => any;
    ontouchstart?: (this: GlobalEventHandlers, ev: TouchEvent) => any;
    ontransitioncancel: (this: GlobalEventHandlers, ev: TransitionEvent) => any;
    ontransitionend: (this: GlobalEventHandlers, ev: TransitionEvent) => any;
    ontransitionrun: (this: GlobalEventHandlers, ev: TransitionEvent) => any;
    ontransitionstart: (this: GlobalEventHandlers, ev: TransitionEvent) => any;
    onvolumechange: (this: GlobalEventHandlers, ev: Event) => any;
    onwaiting: (this: GlobalEventHandlers, ev: Event) => any;
    onwebkitanimationend: (this: GlobalEventHandlers, ev: Event) => any;
    onwebkitanimationiteration: (this: GlobalEventHandlers, ev: Event) => any;
    onwebkitanimationstart: (this: GlobalEventHandlers, ev: Event) => any;
    onwebkittransitionend: (this: GlobalEventHandlers, ev: Event) => any;
    onwheel: (this: GlobalEventHandlers, ev: WheelEvent) => any;
    autofocus: boolean;
    readonly dataset: DOMStringMap;
    nonce?: string;
    tabIndex: number;
    blur(): void;
    focus(options?: FocusOptions): void;
    readonly $fastController: Controller;
    connectedCallback(): void;
    disconnectedCallback(): void;
    attributeChangedCallback(name: string, oldValue: string, newValue: string): void;
};

/**
 * AuthConfig DI interface.
 *
 * @public
 */
export declare interface AuthConfig {
    /**
     * Logo styles.
     *
     * @remarks
     * Providing `null` will hide the logo. Use content: url(...); to set source.
     *
     * @example Setting a custom logo
     * ```ts
     * logo: css`
     *     content: url(${customLogoImport});
     * `,
     * ```
     */
    logo: ElementStyles | null;
    /**
     * Background styles.
     *
     * @remarks
     * See {@link https://developer.mozilla.org/en-US/docs/Web/CSS/background} for more information.
     *
     * @example Setting a custom background image
     * ```ts
     * background: css`
     *     :host {
     *         background-image: url(${customBGImport});
     *     }
     * `,
     * ```
     */
    background: ElementStyles;
    /**
     * Background video.
     *
     * @remarks
     * Overlays any background image if set. Defaults to `null`.
     */
    backgroundVideo: {
        src: string;
        type: 'video/ogg' | 'video/mp4' | 'video/webm';
    } | null;
    /**
     * Omit any of the internal routes except 'login' and 'not-found'.
     *
     * @remarks
     * Routes specified here will not be configured nor will any internal cross-links to them be displayed.
     *
     * @example
     * ```ts
     * omitRoutes: ['request-account'],
     * ```
     */
    omitRoutes: Exclude<Routes, 'login' | 'not-found'>[];
    /**
     * Map of configuration for each of the primary form fields.
     *
     * @remarks
     * Use to drive inclusion / exclusion, tailor labels etc.
     */
    fields: FieldConfigMap;
    /**
     * The `path` of the micro frontend as defined in the parent / host route.
     *
     * @remarks
     * Used to help resolve internal route links. Defaults to an empty string.
     */
    hostPath: string;
    /**
     * The default URL to route the user to after a successful login.
     *
     * @remarks
     * User.lastPath() is any trumps this value.
     */
    defaultRedirectUrl: string;
    /**
     * The forgot password return URL which is used in the email template.
     */
    forgotPasswordReturnUrl: string;
    /**
     * Omit certain return URLs which the session service may have captured.
     *
     * @example
     * ```ts
     * omitRedirectUrls: ['/not-found'],
     * ```
     */
    omitRedirectUrls: string[];
    /**
     * The routing method called post login and logout.
     *
     * @remarks
     * By default, we use the FASTRouter which internally invokes the native History APIs. The post login url is the last
     * url visited by the user by default or undefined. The post logout url is a slash `/` by default. When overriding
     * this, you should include some protection and may want to ignore when the URL is equal to the current url.
     *
     * @param url - The url to route to or undefined.
     */
    routeToUrl: (url: string | undefined) => void;
    /**
     * SSO configuration.
     *
     * @remarks
     * Providing `null` excludes the SSO journey option completely.
     */
    sso: SSOConfig | null;
    /**
     * Display arbitrary version information.
     *
     * @remarks
     * Applications may choose to set this to display their Application release version on the login form.
     *
     * @example
     * ```ts
     * versionInformation: 'Version 3.0.0',
     * ```
     */
    versionInformation?: string;
    /**
     * Feedback delay.
     *
     * @remarks
     * The amount of seconds to display user feedback messages, such as "check your inbox" etc. Defaults to 3 seconds.
     */
    feedbackDelay?: number;
}

/**
 * AuthConfig DI key.
 *
 * @internal
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 */
export declare const AuthConfig: InterfaceSymbol<AuthConfig>;

/**
 * @public
 */
export declare type AuthDTO = LoginDTO | LogoutDTO | PasswordManagementDTO;

/**
 * @public
 */
export declare type AuthEntity = LoginEntity | LogoutEntity | PasswordManagementEntity;

/**
 * @public
 */
export declare type AuthEventMap = StoreRootEventDetailMap & AuthMachineEventMap & {
    'auth-login': LoginParams;
    'auth-logout': void;
    'auth-change-password': ChangePasswordParams;
    'auth-forgot-password': ForgotPasswordParams;
    'auth-reset-password': ResetPasswordParams;
};

/**
 * @public
 */
export declare type AuthFormEntryEventMap = {
    'auth-autofill-form': void;
    'auth-organisation-changed': string;
    'auth-username-changed': string;
    'auth-email-changed': string;
    'auth-password-changed': string;
    'auth-password2-changed': string;
    'auth-showPasswords-changed': boolean;
};

/**
 * AuthFormEntryStore interface.
 * @public
 */
export declare interface AuthFormEntryStore extends Store {
    readonly host: string;
    readonly organisation: string;
    readonly username: string;
    readonly orgUsername: string;
    readonly email: string;
    readonly password: string;
    readonly password2: string;
    readonly showPasswords: boolean;
    readonly hasPasswordExpired: boolean;
    readonly passwordResetToken: string;
    readonly message: string;
    readonly hasErrors: boolean;
    readonly mfaCode: string;
    readonly idps: IDP[];
    readonly selectedIDP: string;
    readonly ssoToggled: boolean;
    readonly termsAgreed: boolean;
    onOrganisationChanged(event: CustomEvent<string>): void;
    onUsernameChanged(event: CustomEvent<string>): void;
    onEmailChanged(event: CustomEvent<string>): void;
    onPasswordChanged(event: CustomEvent<string>): void;
    onPassword2Changed(event: CustomEvent<string>): void;
    onShowPasswordsChanged(event: CustomEvent<boolean>): void;
    onAutofillForm(event: CustomEvent<void>): void;
}

/**
 * DI key of the store.
 * @internal
 */
export declare const AuthFormEntryStore: InterfaceSymbol<Key>;

/**
 * @beta
 * @privateRemarks
 * A hosted version of the MF that doesn't set up a design system or components. This is what apps would use to truly
 * customise the MF for their needs via define.ts.
 */
export declare class AuthHosted extends Auth {
    registerCommonComponents(): Promise<void>;
}

/**
 * AuthMachine interface.
 * @public
 */
export declare interface AuthMachine extends Machine<AuthMachineContext, AuthMachineEvent> {
}

/**
 * AuthMachine DI key.
 * @internal
 */
export declare const AuthMachine: InterfaceSymbol<AuthMachine>;

/**
 * AuthMachineContext interface.
 * @remarks
 * Transient state during the machine's execution.
 * @public
 */
export declare interface AuthMachineContext extends MachineContext {
    /**
     * Authentication event params.
     */
    params?: AuthMachineEventParams;
    /**
     * The login/login DTO from the fetch machine.
     */
    dto: AuthDTO;
    /**
     * The login/login Entity mapped from the DTO.
     */
    entity: AuthEntity;
    /**
     * The user, either authenticated or anonymous.
     */
    user: User;
}

/**
 * AuthMachineEvent type.
 * @remarks
 * The send action events used to invoke the machine.
 * @public
 */
export declare type AuthMachineEvent = {
    type: 'login';
    params: LoginParams;
} | {
    type: 'logout';
} | {
    type: 'change-password';
    params: ChangePasswordParams;
} | {
    type: 'forgot-password';
    params: ForgotPasswordParams;
} | {
    type: 'reset-password';
    params: ResetPasswordParams;
} | DoneInvokeEvent<unknown> | ErrorEvent_2<unknown>;

/**
 * AuthMachineEventMap type.
 * @remarks
 * The mediation CustomEvent used to invoke machine actions.
 * @public
 */
export declare type AuthMachineEventMap = {
    'auth-machine-event': AuthMachineEvent;
};

/**
 * AuthMachineEventParams type.
 * @public
 */
export declare type AuthMachineEventParams = LoginParams | ForgotPasswordParams | ChangePasswordParams | ResetPasswordParams | QueryParams;

/**
 * AuthMessageMapper interface.
 * @public
 */
export declare interface AuthMessageMapper extends MessageMapper<AuthMessageMapperLookup> {
}

/**
 * AuthMessageMapper DI key.
 *
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 *
 * @internal
 */
export declare const AuthMessageMapper: InterfaceSymbol<AuthMessageMapper>;

/**
 * @public
 */
export declare type AuthMessageMapperLookup = {
    /**
     * Login
     */
    [MESSAGE_TYPE.LOGIN]: LoginMapper;
    [MESSAGE_TYPE.LOGIN_ACK]: LoginMapper;
    [MESSAGE_TYPE.LOGIN_NACK]: LoginMapper;
    [MESSAGE_TYPE.LOGIN_DETAILS_ACK]: LoginMapper;
    [MESSAGE_TYPE.LOGIN_DETAILS_NACK]: LoginMapper;
    /**
     * Logout
     */
    [MESSAGE_TYPE.LOGOUT_ACK]: LogoutMapper;
    [MESSAGE_TYPE.LOGOUT_NACK]: LogoutMapper;
    /**
     * Password management
     */
    [MESSAGE_TYPE.FORGOT_PASSWORD]: PasswordManagementMapper;
    [MESSAGE_TYPE.CHANGE_PASSWORD]: PasswordManagementMapper;
    [MESSAGE_TYPE.RESET_PASSWORD]: PasswordManagementMapper;
    /**
     * Generic
     * TODO: update these to use a generic mapper
     */
    [MESSAGE_TYPE.EVENT_NACK]: LogoutMapper;
};

/**
 * AuthStore interface.
 * @remarks
 * This is the root store for the foundation-auth package.
 * @public
 */
export declare interface AuthStore extends StoreRoot {
    readonly isPending: boolean;
    readonly formEntry: AuthFormEntryStore;
    /**
     * Auth workflows and transient state (context in xstate lingo).
     */
    readonly authMachine: AuthMachine;
    /**
     * @param event - The machine mediation event.
     */
    onMachineEvent(event: CustomEvent<AuthEventMap['auth-machine-event']>): void;
    onLogin(event: CustomEvent<LoginParams>): void;
    onLogout(event: CustomEvent<void>): void;
    onChangePassword(event: CustomEvent<ChangePasswordParams>): void;
    onForgotPassword(event: CustomEvent<ForgotPasswordParams>): void;
    onResetPassword(event: CustomEvent<ResetPasswordParams>): void;
}

/**
 * DI key of the store.
 * @internal
 */
export declare const AuthStore: InterfaceSymbol<Key>;

/**
 * @internal
 */
export declare const backButton: <T extends ConfigHost>(binding: Binding) => ViewTemplate<T, any>;

/**
 * @internal
 */
export declare class BaseRoute extends ConfigHostElement {
    store: AuthStore;
    user: User;
    credentialManager: CredentialManager;
    /**
     * TODO: Replace with machine
     */
    message: string;
    hasErrors: boolean;
    connectedCallback(): void;
    setError(message: string): void;
    clearError(): void;
    getSubRoutePath(routeName: Routes | string): string;
    onBack: () => void;
    onNavigate: (path: string) => void;
    attemptAutofill(): void;
}

/**
 * @public
 */
export declare type BasicCredentials = {
    type: CredentialType_2 & CredentialType_2.BASIC;
    username: string;
    password: string;
};

/**
 * @public
 */
export declare let CHANGE_PASSWORD_URL: string;

/**
 * @public
 */
export declare type ChangePasswordParams = {
    username: string;
    oldPassword: string;
    newPassword: string;
    requester?: string;
};

/**
 * @internal
 */
export declare type ConfigHost = {
    config: AuthConfig;
};

/**
 * @internal
 * @privateRemarks
 * For services / constructor injection, using `@optional(AuthConfig) config = defaultAuthConfig;` works as expected.
 * However, for elements, the `@optional` decorator isn't viable. This base element provides an alternative approach.
 */
export declare class ConfigHostElement extends ConfigHostElement_base implements ConfigHost {
    container: Container;
    config: AuthConfig;
    connectedCallback(): void;
}

declare const ConfigHostElement_base: abstract new (...args: any[]) => {
    $emit<K extends "auth-autofill-form" | "auth-organisation-changed" | "auth-username-changed" | "auth-email-changed" | "auth-password-changed" | "auth-password2-changed" | "auth-showPasswords-changed" | "store-connected" | "store-disconnected" | "store-ready" | "auth-machine-event" | "auth-login" | "auth-logout" | "auth-change-password" | "auth-forgot-password" | "auth-reset-password">(...args: EventMap[K] extends void ? [type: K, options?: EmitOptions] : [type: K, detail: EventMap[K], options?: EmitOptions]): EmitReturn;
    accessKey: string;
    readonly accessKeyLabel: string;
    autocapitalize: string;
    dir: string;
    draggable: boolean;
    hidden: boolean;
    inert: boolean;
    innerText: string;
    lang: string;
    readonly offsetHeight: number;
    readonly offsetLeft: number;
    readonly offsetParent: Element;
    readonly offsetTop: number;
    readonly offsetWidth: number;
    outerText: string;
    spellcheck: boolean;
    title: string;
    translate: boolean;
    attachInternals(): ElementInternals;
    click(): void;
    addEventListener<K_1 extends keyof HTMLElementEventMap>(type: K_1, listener: (this: HTMLElement, ev: HTMLElementEventMap[K_1]) => any, options?: boolean | AddEventListenerOptions): void;
    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;
    removeEventListener<K_2 extends keyof HTMLElementEventMap>(type: K_2, listener: (this: HTMLElement, ev: HTMLElementEventMap[K_2]) => any, options?: boolean | EventListenerOptions): void;
    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;
    readonly attributes: NamedNodeMap;
    readonly classList: DOMTokenList;
    className: string;
    readonly clientHeight: number;
    readonly clientLeft: number;
    readonly clientTop: number;
    readonly clientWidth: number;
    id: string;
    readonly localName: string;
    readonly namespaceURI: string;
    onfullscreenchange: (this: Element, ev: Event) => any;
    onfullscreenerror: (this: Element, ev: Event) => any;
    outerHTML: string;
    readonly ownerDocument: Document;
    readonly part: DOMTokenList;
    readonly prefix: string;
    readonly scrollHeight: number;
    scrollLeft: number;
    scrollTop: number;
    readonly scrollWidth: number;
    readonly shadowRoot: ShadowRoot;
    slot: string;
    readonly tagName: string;
    attachShadow(init: ShadowRootInit): ShadowRoot;
    closest<K_3 extends keyof HTMLElementTagNameMap>(selector: K_3): HTMLElementTagNameMap[K_3];
    closest<K_4 extends keyof SVGElementTagNameMap>(selector: K_4): SVGElementTagNameMap[K_4];
    closest<E extends Element = Element>(selectors: string): E;
    getAttribute(qualifiedName: string): string;
    getAttributeNS(namespace: string, localName: string): string;
    getAttributeNames(): string[];
    getAttributeNode(qualifiedName: string): Attr;
    getAttributeNodeNS(namespace: string, localName: string): Attr;
    getBoundingClientRect(): DOMRect;
    getClientRects(): DOMRectList;
    getElementsByClassName(classNames: string): HTMLCollectionOf<Element>;
    getElementsByTagName<K_5 extends keyof HTMLElementTagNameMap>(qualifiedName: K_5): HTMLCollectionOf<HTMLElementTagNameMap[K_5]>;
    getElementsByTagName<K_6 extends keyof SVGElementTagNameMap>(qualifiedName: K_6): HTMLCollectionOf<SVGElementTagNameMap[K_6]>;
    getElementsByTagName(qualifiedName: string): HTMLCollectionOf<Element>;
    getElementsByTagNameNS(namespaceURI: "http://www.w3.org/1999/xhtml", localName: string): HTMLCollectionOf<HTMLElement>;
    getElementsByTagNameNS(namespaceURI: "http://www.w3.org/2000/svg", localName: string): HTMLCollectionOf<SVGElement>;
    getElementsByTagNameNS(namespace: string, localName: string): HTMLCollectionOf<Element>;
    hasAttribute(qualifiedName: string): boolean;
    hasAttributeNS(namespace: string, localName: string): boolean;
    hasAttributes(): boolean;
    hasPointerCapture(pointerId: number): boolean;
    insertAdjacentElement(where: InsertPosition, element: Element): Element;
    insertAdjacentHTML(position: InsertPosition, text: string): void;
    insertAdjacentText(where: InsertPosition, data: string): void;
    matches(selectors: string): boolean;
    releasePointerCapture(pointerId: number): void;
    removeAttribute(qualifiedName: string): void;
    removeAttributeNS(namespace: string, localName: string): void;
    removeAttributeNode(attr: Attr): Attr;
    requestFullscreen(options?: FullscreenOptions): Promise<void>;
    requestPointerLock(): void;
    scroll(options?: ScrollToOptions): void;
    scroll(x: number, y: number): void;
    scrollBy(options?: ScrollToOptions): void;
    scrollBy(x: number, y: number): void;
    scrollIntoView(arg?: boolean | ScrollIntoViewOptions): void;
    scrollTo(options?: ScrollToOptions): void;
    scrollTo(x: number, y: number): void;
    setAttribute(qualifiedName: string, value: string): void;
    setAttributeNS(namespace: string, qualifiedName: string, value: string): void;
    setAttributeNode(attr: Attr): Attr;
    setAttributeNodeNS(attr: Attr): Attr;
    setPointerCapture(pointerId: number): void;
    toggleAttribute(qualifiedName: string, force?: boolean): boolean;
    webkitMatchesSelector(selectors: string): boolean;
    readonly baseURI: string;
    readonly childNodes: NodeListOf<ChildNode>;
    readonly firstChild: ChildNode;
    readonly isConnected: boolean;
    readonly lastChild: ChildNode;
    readonly nextSibling: ChildNode;
    readonly nodeName: string;
    readonly nodeType: number;
    nodeValue: string;
    readonly parentElement: HTMLElement;
    readonly parentNode: ParentNode;
    readonly previousSibling: ChildNode;
    textContent: string;
    appendChild<T extends Node>(node: T): T;
    cloneNode(deep?: boolean): Node;
    compareDocumentPosition(other: Node): number;
    contains(other: Node): boolean;
    getRootNode(options?: GetRootNodeOptions): Node;
    hasChildNodes(): boolean;
    insertBefore<T_1 extends Node>(node: T_1, child: Node): T_1;
    isDefaultNamespace(namespace: string): boolean;
    isEqualNode(otherNode: Node): boolean;
    isSameNode(otherNode: Node): boolean;
    lookupNamespaceURI(prefix: string): string;
    lookupPrefix(namespace: string): string;
    normalize(): void;
    removeChild<T_2 extends Node>(child: T_2): T_2;
    replaceChild<T_3 extends Node>(node: Node, child: T_3): T_3;
    readonly ATTRIBUTE_NODE: number;
    readonly CDATA_SECTION_NODE: number;
    readonly COMMENT_NODE: number;
    readonly DOCUMENT_FRAGMENT_NODE: number;
    readonly DOCUMENT_NODE: number;
    readonly DOCUMENT_POSITION_CONTAINED_BY: number;
    readonly DOCUMENT_POSITION_CONTAINS: number;
    readonly DOCUMENT_POSITION_DISCONNECTED: number;
    readonly DOCUMENT_POSITION_FOLLOWING: number;
    readonly DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC: number;
    readonly DOCUMENT_POSITION_PRECEDING: number;
    readonly DOCUMENT_TYPE_NODE: number;
    readonly ELEMENT_NODE: number;
    readonly ENTITY_NODE: number;
    readonly ENTITY_REFERENCE_NODE: number;
    readonly NOTATION_NODE: number;
    readonly PROCESSING_INSTRUCTION_NODE: number;
    readonly TEXT_NODE: number;
    dispatchEvent(event: Event): boolean;
    ariaAtomic: string;
    ariaAutoComplete: string;
    ariaBusy: string;
    ariaChecked: string;
    ariaColCount: string;
    ariaColIndex: string;
    ariaColIndexText: string;
    ariaColSpan: string;
    ariaCurrent: string;
    ariaDisabled: string;
    ariaExpanded: string;
    ariaHasPopup: string;
    ariaHidden: string;
    ariaInvalid: string;
    ariaKeyShortcuts: string;
    ariaLabel: string;
    ariaLevel: string;
    ariaLive: string;
    ariaModal: string;
    ariaMultiLine: string;
    ariaMultiSelectable: string;
    ariaOrientation: string;
    ariaPlaceholder: string;
    ariaPosInSet: string;
    ariaPressed: string;
    ariaReadOnly: string;
    ariaRequired: string;
    ariaRoleDescription: string;
    ariaRowCount: string;
    ariaRowIndex: string;
    ariaRowIndexText: string;
    ariaRowSpan: string;
    ariaSelected: string;
    ariaSetSize: string;
    ariaSort: string;
    ariaValueMax: string;
    ariaValueMin: string;
    ariaValueNow: string;
    ariaValueText: string;
    role: string;
    animate(keyframes: PropertyIndexedKeyframes | Keyframe[], options?: number | KeyframeAnimationOptions): Animation;
    getAnimations(options?: GetAnimationsOptions): Animation[];
    after(...nodes: (string | Node)[]): void;
    before(...nodes: (string | Node)[]): void;
    remove(): void;
    replaceWith(...nodes: (string | Node)[]): void;
    innerHTML: string;
    readonly nextElementSibling: Element;
    readonly previousElementSibling: Element;
    readonly childElementCount: number;
    readonly children: HTMLCollection;
    readonly firstElementChild: Element;
    readonly lastElementChild: Element;
    append(...nodes: (string | Node)[]): void;
    prepend(...nodes: (string | Node)[]): void;
    querySelector<K_7 extends keyof HTMLElementTagNameMap>(selectors: K_7): HTMLElementTagNameMap[K_7];
    querySelector<K_8 extends keyof SVGElementTagNameMap>(selectors: K_8): SVGElementTagNameMap[K_8];
    querySelector<E_1 extends Element = Element>(selectors: string): E_1;
    querySelectorAll<K_9 extends keyof HTMLElementTagNameMap>(selectors: K_9): NodeListOf<HTMLElementTagNameMap[K_9]>;
    querySelectorAll<K_10 extends keyof SVGElementTagNameMap>(selectors: K_10): NodeListOf<SVGElementTagNameMap[K_10]>;
    querySelectorAll<E_2 extends Element = Element>(selectors: string): NodeListOf<E_2>;
    replaceChildren(...nodes: (string | Node)[]): void;
    readonly assignedSlot: HTMLSlotElement;
    oncopy: (this: DocumentAndElementEventHandlers, ev: ClipboardEvent) => any;
    oncut: (this: DocumentAndElementEventHandlers, ev: ClipboardEvent) => any;
    onpaste: (this: DocumentAndElementEventHandlers, ev: ClipboardEvent) => any;
    readonly style: CSSStyleDeclaration;
    contentEditable: string;
    enterKeyHint: string;
    inputMode: string;
    readonly isContentEditable: boolean;
    onabort: (this: GlobalEventHandlers, ev: UIEvent) => any;
    onanimationcancel: (this: GlobalEventHandlers, ev: AnimationEvent) => any;
    onanimationend: (this: GlobalEventHandlers, ev: AnimationEvent) => any;
    onanimationiteration: (this: GlobalEventHandlers, ev: AnimationEvent) => any;
    onanimationstart: (this: GlobalEventHandlers, ev: AnimationEvent) => any;
    onauxclick: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onbeforeinput: (this: GlobalEventHandlers, ev: InputEvent) => any;
    onblur: (this: GlobalEventHandlers, ev: FocusEvent) => any;
    oncancel: (this: GlobalEventHandlers, ev: Event) => any;
    oncanplay: (this: GlobalEventHandlers, ev: Event) => any;
    oncanplaythrough: (this: GlobalEventHandlers, ev: Event) => any;
    onchange: (this: GlobalEventHandlers, ev: Event) => any;
    onclick: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onclose: (this: GlobalEventHandlers, ev: Event) => any;
    oncontextmenu: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    oncuechange: (this: GlobalEventHandlers, ev: Event) => any;
    ondblclick: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    ondrag: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondragend: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondragenter: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondragleave: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondragover: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondragstart: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondrop: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondurationchange: (this: GlobalEventHandlers, ev: Event) => any;
    onemptied: (this: GlobalEventHandlers, ev: Event) => any;
    onended: (this: GlobalEventHandlers, ev: Event) => any;
    onerror: OnErrorEventHandlerNonNull;
    onfocus: (this: GlobalEventHandlers, ev: FocusEvent) => any;
    onformdata: (this: GlobalEventHandlers, ev: FormDataEvent) => any;
    ongotpointercapture: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    oninput: (this: GlobalEventHandlers, ev: Event) => any;
    oninvalid: (this: GlobalEventHandlers, ev: Event) => any;
    onkeydown: (this: GlobalEventHandlers, ev: KeyboardEvent) => any;
    onkeypress: (this: GlobalEventHandlers, ev: KeyboardEvent) => any;
    onkeyup: (this: GlobalEventHandlers, ev: KeyboardEvent) => any;
    onload: (this: GlobalEventHandlers, ev: Event) => any;
    onloadeddata: (this: GlobalEventHandlers, ev: Event) => any;
    onloadedmetadata: (this: GlobalEventHandlers, ev: Event) => any;
    onloadstart: (this: GlobalEventHandlers, ev: Event) => any;
    onlostpointercapture: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onmousedown: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onmouseenter: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onmouseleave: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onmousemove: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onmouseout: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onmouseover: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onmouseup: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onpause: (this: GlobalEventHandlers, ev: Event) => any;
    onplay: (this: GlobalEventHandlers, ev: Event) => any;
    onplaying: (this: GlobalEventHandlers, ev: Event) => any;
    onpointercancel: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointerdown: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointerenter: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointerleave: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointermove: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointerout: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointerover: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointerup: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onprogress: (this: GlobalEventHandlers, ev: ProgressEvent<EventTarget>) => any;
    onratechange: (this: GlobalEventHandlers, ev: Event) => any;
    onreset: (this: GlobalEventHandlers, ev: Event) => any;
    onresize: (this: GlobalEventHandlers, ev: UIEvent) => any;
    onscroll: (this: GlobalEventHandlers, ev: Event) => any;
    onsecuritypolicyviolation: (this: GlobalEventHandlers, ev: SecurityPolicyViolationEvent) => any;
    onseeked: (this: GlobalEventHandlers, ev: Event) => any;
    onseeking: (this: GlobalEventHandlers, ev: Event) => any;
    onselect: (this: GlobalEventHandlers, ev: Event) => any;
    onselectionchange: (this: GlobalEventHandlers, ev: Event) => any;
    onselectstart: (this: GlobalEventHandlers, ev: Event) => any;
    onslotchange: (this: GlobalEventHandlers, ev: Event) => any;
    onstalled: (this: GlobalEventHandlers, ev: Event) => any;
    onsubmit: (this: GlobalEventHandlers, ev: SubmitEvent) => any;
    onsuspend: (this: GlobalEventHandlers, ev: Event) => any;
    ontimeupdate: (this: GlobalEventHandlers, ev: Event) => any;
    ontoggle: (this: GlobalEventHandlers, ev: Event) => any;
    ontouchcancel?: (this: GlobalEventHandlers, ev: TouchEvent) => any;
    ontouchend?: (this: GlobalEventHandlers, ev: TouchEvent) => any;
    ontouchmove?: (this: GlobalEventHandlers, ev: TouchEvent) => any;
    ontouchstart?: (this: GlobalEventHandlers, ev: TouchEvent) => any;
    ontransitioncancel: (this: GlobalEventHandlers, ev: TransitionEvent) => any;
    ontransitionend: (this: GlobalEventHandlers, ev: TransitionEvent) => any;
    ontransitionrun: (this: GlobalEventHandlers, ev: TransitionEvent) => any;
    ontransitionstart: (this: GlobalEventHandlers, ev: TransitionEvent) => any;
    onvolumechange: (this: GlobalEventHandlers, ev: Event) => any;
    onwaiting: (this: GlobalEventHandlers, ev: Event) => any;
    onwebkitanimationend: (this: GlobalEventHandlers, ev: Event) => any;
    onwebkitanimationiteration: (this: GlobalEventHandlers, ev: Event) => any;
    onwebkitanimationstart: (this: GlobalEventHandlers, ev: Event) => any;
    onwebkittransitionend: (this: GlobalEventHandlers, ev: Event) => any;
    onwheel: (this: GlobalEventHandlers, ev: WheelEvent) => any;
    autofocus: boolean;
    readonly dataset: DOMStringMap;
    nonce?: string;
    tabIndex: number;
    blur(): void;
    focus(options?: FocusOptions): void;
    readonly $fastController: Controller;
    connectedCallback(): void;
    disconnectedCallback(): void;
    attributeChangedCallback(name: string, oldValue: string, newValue: string): void;
};

/**
 * Configure the auth micro frontend settings.
 *
 * @remarks
 * This is primarily for general settings, rather than re-defining the element, static templating / style changes.
 *
 * @param config - A partial AuthConfig.
 *
 * @example Configuring auth on lazy load
 * ```ts
 * name: 'auth',
 * path: 'auth',
 * title: 'Authenticate',
 * element: async () => {
 *   const { configure, Auth } = await import('@genesislcap/foundation-auth');
 *   configure({
 *     hostPath: 'auth',
 *     defaultRedirectUrl: 'dashboard',
 *     omitRoutes: ['request-account'],
 *     logo: myCompanyLogo,
 *     background: myAuthBG,
 *   });
 *   return Auth;
 * },
 * layout: authLayout,
 * settings: { public: true },
 * childRouters: true,
 * ```
 *
 * @public
 * @privateRemarks
 * We can tailor the spreading logic after we put it to use. Keeping it simple for now.
 */
export declare function configure(config: Partial<AuthConfig>): void;

/**
 * createHTTPHeadersFromDTO.
 * @param dto - DTO being sent to the server.
 * @param contentType - Optional content-type, defaults to `application/json; charset=UTF-8`.
 * @public
 */
export declare function createHTTPHeadersFromDTO(dto: {
    SOURCE_REF?: string;
    USER_NAME?: string;
}, contentType?: string): HeadersInit;

/**
 * A factory to create a MessageMapper.
 * @returns A MessageMapper instance.
 *
 * @public
 */
export declare const createMessageMapper: <TLookup extends MessageMapperLookup, K extends keyof TLookup = keyof TLookup>() => MessageMapper<TLookup, K>;

/**
 * Represents user credentials.
 * @public
 */
declare type CredentialData_2 = PasswordCredentialData & {
    password?: string;
};
export { CredentialData_2 as CredentialData }

/**
 * CredentialManager interface.
 *
 * @remarks
 * A system for managing user credentials.
 *
 * @public
 */
export declare interface CredentialManager {
    /**
     * Validates basic credentials (username and password).
     * @public
     * @param credentials - The credentials to validate.
     * @returns `true` if the credentials are valid, or `false` otherwise.
     */
    validateBasicCredentials(credentials: BasicCredentials): boolean;
    /**
     * Validates refresh credentials.
     * @public
     * @param credentials - The credentials to validate.
     * @returns `true` if the credentials are valid, or `false` otherwise.
     */
    validateRefreshCredentials(credentials: RefreshCredentials): boolean;
    /**
     * Validates SSO credentials.
     * @public
     * @param credentials - The credentials to validate.
     * @returns `true` if the credentials are valid, or `false` otherwise.
     */
    validateSSOCredentials(credentials: SSOCredentials): boolean;
    /**
     * Validates MFA credentials.
     * @public
     * @param credentials - The credentials to validate.
     * @returns `true` if the credentials are valid, or `false` otherwise.
     */
    validateMFACredentials(credentials: MFACredentials): boolean;
    /**
     * Validate user credential data returned from the container or a cookie.
     *
     * @remarks
     * This can be called to ensure the credential is in the format this version of the manager expects. This is mainly
     * for dealing with malformed cookies.
     *
     * @privateRemarks
     * This can occur if the credential was saved using custom App code or via an early version of the manager itself.
     * The credential may be missing certain field values.
     *
     * @public
     * @param data - The credential data to validate.
     * @param ensurePassword - Check for the existence of a password. PasswordCredentials will have this, but cookies are considered valid without.
     */
    validateUserCredentialData(data: CredentialData_2, ensurePassword?: boolean): boolean;
    /**
     * Normalise legacy credential data.
     *
     * @remarks
     * Older applications may have legacy credential data that needs migrating to the latest format the manager expects.
     * If the input CredentialData is already formatted as such, it will be returned as is. Otherwise, we check if any
     * cookie input is already formatted as such, and if so return it as CredentialData. If neither inputs are valid,
     * we will attempt a best effort normalisation to create valid CredentialData, or abort and return undefined.
     *
     * @public
     * @param data - The credential data to normalise.
     * @param cookie - The unknown cookie data to normalise.
     * @returns A tuple of the best effort normalisation of the inputs to the CredentialData format, and a boolean to indicate if we can remove the cookie.
     */
    normaliseLegacyCredentialData(data?: CredentialData_2, cookie?: CredentialData_2): [CredentialData_2 | undefined, boolean];
    /**
     * Stores the specified credential data in the browser's credential manager.
     * @see https://developer.mozilla.org/en-US/docs/Web/API/CredentialsContainer
     * @public
     * @param data - The credential data to store.
     * @returns A Promise that resolves to the stored credential object, or `undefined` if storage fails.
     */
    storeCredentialsInContainer(data: CredentialData_2): Promise<Credential | undefined>;
    /**
     * Retrieves credential data from the browser's credential manager.
     * @public
     * @param options - Options for filtering the retrieved credentials, if any.
     * @returns A Promise that resolves to the retrieved credential data, or `null` if no matching credentials were found.
     */
    getCredentialsFromContainer(options?: GetCredentialOptions): Promise<CredentialData_2 | null>;
    /**
     * Stores the specified credential data in a browser cookie.
     * @public
     * @param data - The credential data to store.
     * @returns `true` if storage was successful, or `false` otherwise.
     */
    storeCredentialsInCookie(data: CredentialData_2): boolean;
    /**
     * Retrieves credential data from a browser cookie.
     * @public
     * @returns The retrieved credential data, or `undefined` if no matching data was found.
     */
    getCredentialsFromCookie(): CredentialData_2 | undefined;
    /**
     * Stores user credentials securely.
     * @public
     * @param data - The credential data to be stored.
     * @returns A Promise that resolves to a boolean indicating if the credentials were stored successfully.
     */
    storeCredentials(data: CredentialData_2): Promise<boolean>;
    /**
     * Retrieves stored credentials.
     * @public
     * @param options - An object containing options for retrieving credentials.
     * @returns A Promise that resolves to a CredentialData object if the credentials are found, or undefined otherwise.
     */
    getCredentials(options?: GetCredentialOptions): Promise<CredentialData_2 | undefined>;
    /**
     * Removes the user's credential cookie.
     * @remarks
     * This is generally called when migrating a user's saved credentials from a cookie to the secure container.
     * @public
     */
    removeCookie(): void;
    /**
     * Prevents silent access by requiring the user to authenticate before making API requests.
     * @public
     */
    preventSilentAccess(): Promise<void>;
}

/**
 * CredentialManager DI key.
 *
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 *
 * @internal
 */
export declare const CredentialManager: InterfaceSymbol<CredentialManager>;

/**
 * The configuration for the CredentialManager
 * @public
 */
export declare interface CredentialManagerConfig {
    cookie: CredentialManagerCookieConfig;
}

/**
 * The DI key which can be used for explicit configuration by the host application
 * @internal
 */
export declare const CredentialManagerConfig: InterfaceSymbol<CredentialManagerConfig>;

/**
 * The configuration options for the CredentialManager cookie
 * @public
 */
export declare interface CredentialManagerCookieConfig {
    path: string;
    name: string;
    expires: number | Date;
    storePasswords?: boolean;
}

/**
 * Union of all credential types.
 * @public
 */
export declare type Credentials = BasicCredentials | SSOCredentials | JWTCredentials | RefreshCredentials | MFACredentials;

/**
 * The default separator used for splitting credential parts.
 * @public
 */
export declare const credentialSeparator = ":";

/**
 * Types of credentials supported.
 * @public
 */
declare enum CredentialType_2 {
    BASIC = "BASIC",
    SSO = "SSO",
    JWT = "JWT",
    REFRESH = "REFRESH",
    MFA = "MFA"
}
export { CredentialType_2 as CredentialType }

/**
 * Default AuthConfig DI implementation.
 * @public
 */
export declare const defaultAuthConfig: AuthConfig;

/**
 * Default implementation of the store.
 * @public
 */
export declare class DefaultAuthFormEntryStore extends AbstractStore<AuthFormEntryStore, AuthFormEntryEventMap, InternalEventMap> implements AuthFormEntryStore {
    protected config: AuthConfig;
    protected credentialManager: CredentialManager;
    host: string;
    organisation: string;
    username: string;
    email: string;
    password: string;
    password2: string;
    showPasswords: boolean;
    hasPasswordExpired: boolean;
    passwordResetToken: string;
    message: string;
    hasErrors: boolean;
    mfaCode: string;
    idps: IDP[];
    selectedIDP: string;
    ssoToggled: boolean;
    termsAgreed: boolean;
    get orgUsername(): string;
    constructor();
    private autofill;
    onOrganisationChanged: EventListener;
    onUsernameChanged: EventListener;
    onEmailChanged: EventListener;
    onPasswordChanged: EventListener;
    onPassword2Changed: EventListener;
    onShowPasswordsChanged: EventListener;
    onAutofillForm: EventListener;
}

/**
 * Default AuthMachine.
 * @public
 */
export declare class DefaultAuthMachine extends AbstractMachine<AuthMachineContext, AuthMachineEvent> implements AuthMachine {
    private user;
    private fetchMachine;
    private cm;
    private uuid;
    private messageMapper;
    private config;
    constructor(user: User, fetchMachine: FetchMachine, cm: CredentialManager, uuid: UUID, messageMapper: AuthMessageMapper, config: AuthConfig);
    start(options?: InterpreterOptions<typeof DefaultAuthMachine.machine>): void;
    /**
     * AuthMachine is a singleton.
     */
    getFromContainer(): this;
    protected captureAuthQueryParams(): QueryParams;
    protected convertQueryParamsToLoginParams(params: QueryParams): LoginParams;
    protected createFetchMachineEvent(url: string, msg?: {}): FetchMachineEvent;
    protected onIdleEvents: () => {
        login: {
            actions: string[];
            target: string;
        };
        "forgot-password": {
            actions: string[];
            target: string;
        };
        "change-password": {
            actions: string[];
            target: string;
        };
        "reset-password": {
            actions: string[];
            target: string;
        };
    };
    protected onDoneDTO: () => {
        actions: string[];
        target: string;
    };
}

/**
 * Default AuthMachineContext.
 * @public
 */
export declare const defaultAuthMachineContext: Partial<AuthMachineContext>;

/**
 * Default AuthMessageMapper.
 * @public
 */
export declare class DefaultAuthMessageMapper extends DefaultMessageMapper<AuthMessageMapperLookup> implements AuthMessageMapper {
    protected loginMapper: LoginMapper;
    protected logoutMapper: LogoutMapper;
    protected passwordMapper: PasswordManagementMapper;
    constructor(loginMapper: LoginMapper, logoutMapper: LogoutMapper, passwordMapper: PasswordManagementMapper);
}

/**
 * Default implementation of the store.
 * @public
 */
export declare class DefaultAuthStore extends AbstractStoreRoot<AuthStore, AuthEventMap, InternalAuthEventMap> implements AuthStore {
    readonly config: AuthConfig;
    readonly authMachine: AuthMachine;
    readonly formEntry: AuthFormEntryStore;
    constructor(config: AuthConfig, authMachine: AuthMachine, formEntry: AuthFormEntryStore);
    get isPending(): boolean;
    onMachineEvent: EventListener;
    onLogin: EventListener;
    onLogout: EventListener;
    onChangePassword: EventListener;
    onForgotPassword: EventListener;
    onResetPassword: EventListener;
}

/**
 * Default CredentialManager.
 * @public
 */
export declare class DefaultCredentialManager implements CredentialManager {
    private config;
    constructor(config?: CredentialManagerConfig);
    validateBasicCredentials(credentials: BasicCredentials): boolean;
    validateRefreshCredentials(credentials: RefreshCredentials): boolean;
    validateSSOCredentials(credentials: SSOCredentials): boolean;
    validateMFACredentials(credentials: MFACredentials): boolean;
    validateUserCredentialData(data: CredentialData_2, ensurePassword?: boolean): boolean;
    normaliseLegacyCredentialData(data?: CredentialData_2, cookie?: CredentialData_2): [CredentialData_2 | undefined, boolean];
    storeCredentialsInContainer(data: CredentialData_2): Promise<Credential | undefined>;
    getCredentialsFromContainer(options?: CredentialRequestOptions): Promise<CredentialData_2 | null>;
    storeCredentialsInCookie(data: CredentialData_2): boolean;
    getCredentialsFromCookie(): CredentialData_2 | undefined;
    storeCredentials(data: CredentialData_2): Promise<boolean>;
    getCredentials(options?: GetCredentialOptions): Promise<CredentialData_2 | undefined>;
    removeCookie(): void;
    preventSilentAccess(): Promise<void>;
}

/**
 * The default configuration for the CredentialManager service.
 * @public
 */
export declare const defaultCredentialManagerConfig: CredentialManagerConfig;

/**
 * The default request options for the CredentialManager service.
 * @public
 */
export declare const defaultCredentialRequestOptions: GetCredentialOptions;

/**
 * Default LoginMapper.
 * @public
 */
export declare class DefaultLoginMapper implements LoginMapper {
    protected uuid: UUID;
    /**
     * {@inheritDoc Mapper.toEntity}
     */
    toEntity: (dto: LoginDTO) => LoginEntity;
    /**
     * {@inheritDoc Mapper.toDTO}
     */
    toDTO: (entity: LoginEntity) => LoginDTO;
    protected fromSystemDTO: (system: System_2) => System;
    protected fromProductDTO: (products: Product_2[]) => Product[];
}

/**
 * Default LogoutMapper.
 * @public
 */
export declare class DefaultLogoutMapper implements LogoutMapper {
    /**
     * {@inheritDoc Mapper.toEntity}
     */
    toEntity: (dto: LogoutDTO) => LogoutEntity;
}

/**
 * Default LogoutUtility.
 *
 * @public
 */
export declare class DefaultLogoutUtility implements LogoutUtility {
    /** @internal */
    private config;
    /** @internal */
    private user;
    /** {@inheritDoc LogoutUtility.run} */
    run(): void;
}

/**
 * @public
 */
export declare class DefaultMessageMapper<TLookup extends MessageMapperLookup, K extends keyof TLookup = keyof TLookup> implements MessageMapper<TLookup, K> {
    private map;
    /** {@inheritDoc MessageMapper.set} */
    set(key: K, mapper: TLookup[K]): void;
    /**
     * Get a mapper by message type.
     * @param key - The message type as key.
     * @returns The mapper if it exists, otherwise undefined.
     * @public
     */
    get(key: K): TLookup[K] | undefined;
    /**
     * Has a mapper for key.
     * @param key - The message type as key.
     * @returns True if it exists, otherwise false.
     *
     * @public
     */
    has(key: K): boolean;
    /**
     * Delete a mapper.
     * @param key - The message type as key.
     * @returns True if successful, otherwise false.
     *
     * @public
     */
    delete(key: K): boolean;
    /**
     * Clear mappers.
     * @public
     */
    clear(): void;
    /**
     * The size of the mapper map.
     * @returns number
     *
     * @public
     */
    get size(): number;
}

/**
 * Default PasswordManagementMapper.
 * @public
 */
export declare class DefaultPasswordManagementMapper implements PasswordManagementMapper {
    protected uuid: UUID;
    /**
     * {@inheritDoc Mapper.toDTO}
     */
    toDTO: (entity: PasswordManagementEntity) => PasswordManagementDTO;
}

/**
 * The default template options this MF has been created with.
 * @beta
 * @privateRemarks
 * This will likely evolve into the shell style PWA + FDC3 manifest setup, but that needs more work to evolve into MVP.
 * Hosts should be able to figure out everything they will need to do to fully customise a MF. Currently, they
 * import these `defaultTemplateOptions` and the host dev overrides. Each TemplateComponents key must be a mandatory
 * override, given in hosted mode the MFs won't be registering fallbacks as this would be wasteful, bloat etc.
 * I've added the components list to the package.json \> config block for now, but I'm not using it here.
 */
export declare const defaultTemplateOptions: TemplateOptions;

/**
 * Default User implementation.
 * @public
 */
export declare class DefaultUser implements User {
    /** @internal */
    protected config: UserConfig;
    /** {@inheritDoc UserPathHistory.pathHistory} */
    pathHistory: string[];
    /** {@inheritDoc UserActionHistory.actionHistory} */
    actionHistory: unknown[];
    /** {@inheritDoc User.isAuthenticated} */
    isAuthenticated: boolean;
    /** {@inheritDoc User.userKVs} */
    userKVs: {
        [key: string]: any;
    };
    /** {@inheritDoc User.details} */
    details: Details;
    /** {@inheritDoc User.permission} */
    permission: string[];
    /** {@inheritDoc User.profile} */
    profile: string[];
    /** {@inheritDoc User.sourceRef} */
    sourceRef: string;
    /** {@inheritDoc User.userName} */
    userName: string;
    /** {@inheritDoc User.set} */
    set(entity: Partial<LoginAck>): this;
    /** {@inheritDoc User.unset} */
    unset(): this;
    /** @internal */
    protected userNameChanged(): void;
    /** {@inheritDoc User.username} */
    get username(): string;
    /** {@inheritDoc User.isAnonymous} */
    get isAnonymous(): boolean;
    /** {@inheritDoc User.isAdmin} */
    isAdmin(): boolean;
    /** {@inheritDoc User.isBanned} */
    isBanned(): boolean;
    /** {@inheritDoc User.hasPermission} */
    hasPermission(permission: string | string[]): boolean;
    /** {@inheritDoc User.hasProfile} */
    hasProfile(profile: string | string[]): boolean;
    /** {@inheritDoc UserPathHistory.trackPath} */
    trackPath(): string;
    /** {@inheritDoc UserPathHistory.clearPaths} */
    clearPaths(): void;
    /** {@inheritDoc UserPathHistory.lastPath} */
    lastPath(): string;
    /** {@inheritDoc UserActionHistory.trackAction} */
    trackAction<TDetails = unknown>(details: TDetails): void;
    /** {@inheritDoc UserActionHistory.clearActions} */
    clearActions(): void;
    /** {@inheritDoc UserActionHistory.lastAction} */
    lastAction(): unknown;
    /** @internal */
    protected hasKey(keys: string[], key: string | string[]): boolean;
    /** @internal */
    protected authenticationChangeListeners: Observer<UserAuthenticationChangeEvent>;
    /** {@inheritDoc User.addAuthenticationChangeListener} */
    addAuthenticationChangeListener(listener: Listener<UserAuthenticationChangeEvent>): () => void;
    /** @internal */
    protected isAuthenticatedChanged(): void;
}

/**
 * Default UserConfig DI implementation.
 * @public
 */
export declare const defaultUserConfig: UserConfig;

/**
 * Re-define the auth micro frontend.
 *
 * @example
 * ```ts
 * import { define, styles, template, defaultTemplateOptions } from '@genesislcap/foundation-auth';
 * const customTemplateOptions = {
 *   ...defaultTemplateOptions,
 *   ...customOptions,
 * }
 * export const AppAuth = define({
 *   name: `nexus-auth`,
 *   template: template(customTemplateOptions),
 *   styles: css`
 *     ${styles(customTemplateOptions)}
 *     some-element {
 *       background-color: #ff00b4;
 *     }
 *  `,
 * });
 * ```
 *
 * @beta
 * @privateRemarks
 * TODO: Use AuthHosted instead of Auth when elements manifest stuff lands, which will drive tagFor etc.
 */
export declare const define: DefineFunction<typeof Auth>;

/**
 * @beta
 * @remarks
 * This is the main definition of this micro frontend which is exposed for user reconfiguration.
 */
export declare const definition: PartialFASTElementDefinition;

/**
 * @public
 */
export declare interface Details {
    readonly system: System | null;
    readonly heartbeatIntervalSecs: number;
    readonly failedLoginAttempts: number;
    readonly rejectedLoginAttempts: number;
    readonly lastLoginDatetime: number;
    readonly daysToPasswordExpiry: number;
    readonly product: Product[];
}

/**
 * @public
 */
declare interface Details_2 {
    readonly SYSTEM: System_2;
    readonly HEARTBEAT_INTERVAL_SECS: number;
    readonly FAILED_LOGIN_ATTEMPTS: number;
    readonly REJECTED_LOGIN_ATTEMPTS: number;
    readonly LAST_LOGIN_DATETIME: number;
    readonly DAYS_TO_PASSWORD_EXPIRY: number;
    readonly PRODUCT: Product_2[];
}

/**
 * @internal
 */
export declare const emailField: <T extends BaseRoute>() => ViewTemplate<T, any>;

/**
 * @public
 */
export declare interface EVENT_CHANGE_USER_PASSWORD extends MESSAGE {
    readonly USER_NAME: string;
    readonly DETAILS: {
        readonly OLD_PASSWORD: string;
        readonly NEW_PASSWORD: string;
    };
}

/**
 * @public
 */
export declare interface EVENT_LOGIN_AUTH extends MESSAGE {
    readonly DETAILS: {
        readonly USER_NAME: string;
        readonly PASSWORD: string;
    } | {
        readonly USER_NAME: string;
        readonly REFRESH_AUTH_TOKEN: string;
    } | {
        readonly SSO_TOKEN: string;
    } | {
        readonly JWT: string;
        readonly DOMAIN: string;
    } | {
        readonly MFA_CODE: string;
    };
}

/**
 * @public
 */
export declare interface EVENT_LOGIN_AUTH_ACK extends ACK {
    /**
     * Keeping these 3 here for now as I'm assuming these DTOs will be autogenerated at some point and will contain these.
     */
    readonly SESSION_AUTH_TOKEN: string;
    readonly REFRESH_AUTH_TOKEN: string;
    readonly SESSION_ID: string;
    readonly USER_NAME: string;
    readonly UPDATE_QUEUE: string;
    readonly ZERO_MQ_PROXY_MODE_ENABLED: boolean;
    readonly ZERO_MQ_PROXY_INBOUND_PORT: number;
    readonly ZERO_MQ_PROXY_OUTBOUND_PORT: number;
    /**
     * @privateRemarks
     * This is not the actual "user", it is random JSON / key value pairs set by BE app devs.
     *
     * @example
     * ```json
     * "USER" : {
     *   "USER_TYPE" : "USER",
     *   "USER_ACCESS_TYPE" : "ALL",
     *   "ADDRESS_LINE1" : "JohnDoe Street",
     *   "TEST_CONFIGURATION" : "TEST"
     * }
     * ```
     */
    readonly USER: {
        [key: string]: any;
    };
    readonly DETAILS: Details_2;
    readonly PERMISSION: string[];
    readonly PROFILE: string[];
}

/**
 * @public
 */
export declare interface EVENT_LOGIN_AUTH_NACK extends NACK {
    /**
     * A refresh token may be returned in a NACK on MFA_REQUIRED or similar.
     */
    readonly REFRESH_AUTH_TOKEN: string;
}

/**
 * @public
 */
export declare interface EVENT_LOGIN_DETAILS_ACK extends EVENT_LOGIN_AUTH_ACK {
}

/**
 * @public
 */
export declare interface EVENT_LOGOUT_NACK extends NACK {
}

/**
 * @public
 */
export declare interface EVENT_PASSWORD_RESET_ACTION extends MESSAGE {
    readonly USER_NAME: string;
    readonly DETAILS: {
        readonly USER_NAME: string;
        readonly RESET_TOKEN: string;
        readonly NEW_PASSWORD: string;
    };
}

/**
 * @public
 */
export declare interface EVENT_SELF_SERVICE_PASSWORD_RESET extends MESSAGE {
    readonly USER_NAME: string;
    readonly DETAILS: {
        readonly USER_NAME: string;
        readonly RETURN_URL: string;
    };
}

declare type EventMap = AuthEventMap & AuthFormEntryEventMap & {};

/**
 * Request SSO identity provider list
 *
 * @public
 */
export declare const fetchIDPs: (path?: string, host?: string) => Promise<IDP[]>;

/**
 * @public
 * Could be expanded to allow field ViewTemplates.
 */
export declare type FieldConfig = {
    label: string;
    /**
     * @privateRemarks
     * Added for now to apply defaults, but I'm not convinced we should do this. Could be made reactive after upgrade.
     */
    value?: any;
    /**
     * @remarks
     * We expect fields to be required by default, but you can override to make them optional. Organisation for example.
     */
    required?: boolean;
    /**
     * @remarks
     * A regular expression the control's value should match. Please note the email field has its own built in pattern.
     */
    pattern?: string;
    /**
     * @remarks
     * Used in conjunction with the pattern to explain the conditions.
     */
    title?: string;
};

/**
 * @public
 * @privateRemarks
 * Using null to exclude the organisation field rather than boolean, as it affords cleaner value lookups in the templates.
 */
export declare type FieldConfigMap = {
    organisation: FieldConfig | null;
    username: FieldConfig;
    email: FieldConfig;
    password: FieldConfig;
};

/**
 * @public
 */
export declare let FORGOT_PASSWORD_URL: string;

/**
 * @public
 */
export declare type ForgotPasswordParams = {
    username: string;
    returnUrl: string;
    requester?: string;
};

/**
 * fromDTOAck
 * @param dto - ACK.
 * @public
 */
export declare const fromDTOAck: (dto: ACK) => Ack;

/**
 * fromDTONack
 * @param dto - NACK.
 * @public
 */
export declare const fromDTONack: (dto: NACK) => Nack;

/**
 * @public
 */
export declare const fromDTONackErrorWarningArray: (arr: NACK_ERROR_WARNING[]) => NackErrorWarning[];

/**
 * @public
 */
export declare const fromDTOStringArray: (arr: string[]) => string[];

/**
 * Represents options for retrieving credentials.
 * @public
 */
export declare type GetCredentialOptions = CredentialRequestOptions & {};

/**
 * Gets LogoutUtility from the DI container.
 *
 * @remarks
 * A utility method for host applications that are not using decorators or the DI container.
 *
 * @example
 * ```ts
 * import { getLogoutUtility, LogoutUtility } from '@genesislcap/foundation-auth/logout';
 * ...
 * private logout: LogoutUtility = getLogoutUtility();
 * ...
 * this.logout.run();
 * ```
 *
 * @public
 */
export declare function getLogoutUtility(): LogoutUtility;

/**
 * Get SSO identity provider login URL
 *
 * @public
 */
export declare const getSSOLoginURL: (idp: any, path?: string, host?: string) => string;

/**
 * A utility to get a sub route path taking the host path into account.
 *
 * @param routeName - The route name.
 * @param hostPath - The host path.
 *
 * @public
 */
export declare function getSubRoutePath(routeName: Routes | string, hostPath?: string): string;

/**
 * Gets User from the DI container.
 *
 * @remarks
 * A utility method for host applications that are not using decorators or the DI container.
 *
 * @example
 * ```ts
 * import { getUser, User } from '@genesislcap/foundation-auth/user';
 * ...
 * private user: User = getUser();
 * ```
 *
 * @public
 */
export declare function getUser(): User;

/**
 * hasDTOErrorWarningCode
 * @remarks
 * Checks both the `CODE` and `STATUS_CODE` values for a match.
 * @param dto - NACK.
 * @param code - The error or warning code.
 * @public
 */
export declare const hasDTOErrorWarningCode: (dto: NACK, code: string) => boolean;

/**
 * @public
 */
export declare interface IDP {
    id: string;
    type: string;
}

/**
 * @public
 */
export declare interface IDPResponse {
    ID: string;
    TYPE: string;
}

/**
 * includesErrorWarningCode
 * @public
 */
export declare const includesErrorWarningCode: (arr: NACK_ERROR_WARNING[], code: string) => boolean;

/**
 * @internal
 */
export declare const inputEmit: <K extends KeysMatching<EventMap, string>>(type: K, options?: EmitOptions) => Binding<any, any, any>;

declare type InternalAuthEventMap = {};

declare type InternalEventMap = {};

/**
 * isChangePasswordParams.
 * @remarks
 * ChangePasswordParams.requester is optional, so it is not part of the evaluation.
 * @param params - Potential ChangePasswordParams.
 * @public
 */
export declare function isChangePasswordParams(params: AuthMachineEventParams): params is ChangePasswordParams;

/**
 * isForgotPasswordParams.
 * @remarks
 * ForgotPasswordParams.requester is optional, so it is not part of the evaluation.
 * @param params - Potential ForgotPasswordParams.
 * @public
 */
export declare function isForgotPasswordParams(params: AuthMachineEventParams): params is ForgotPasswordParams;

/**
 * isLoginAckDTO.
 * @param dto - Potential DTO.
 * @public
 */
export declare function isLoginAckDTO(dto: LoginDTO): dto is EVENT_LOGIN_AUTH_ACK;

/**
 * isLoginAckEntity.
 * @param entity - Potential entity.
 * @public
 */
export declare function isLoginAckEntity(entity: LoginEntity): entity is LoginAck;

/**
 * isLoginDetailsAckDTO.
 * @param dto - Potential DTO.
 * @public
 */
export declare function isLoginDetailsAckDTO(dto: LoginDTO): dto is EVENT_LOGIN_DETAILS_ACK;

/**
 * isLoginDetailsAckEntity.
 * @param entity - Potential entity.
 * @public
 */
export declare function isLoginDetailsAckEntity(entity: LoginEntity): entity is LoginDetailsAck;

/**
 * isLoginNackDTO.
 * @param dto - Potential DTO.
 * @public
 */
export declare function isLoginNackDTO(dto: LoginDTO): dto is EVENT_LOGIN_AUTH_NACK;

/**
 * isLoginNackEntity.
 * @param entity - Potential entity.
 * @public
 */
export declare function isLoginNackEntity(entity: LoginEntity): entity is LoginNack;

/**
 * isLoginParams.
 * @param params - Potential LoginParams.
 * @public
 */
export declare function isLoginParams(params: AuthMachineEventParams): params is LoginParams;

/**
 * isLogoutAckDTO.
 * @param dto - Potential DTO.
 * @public
 */
export declare function isLogoutAckDTO(dto: LogoutDTO): dto is LOGOUT_ACK;

/**
 * isLogoutAckEntity.
 * @param entity - Potential entity.
 * @public
 */
export declare function isLogoutAckEntity(entity: LogoutEntity): entity is LogoutAck;

/**
 * isLogoutNackDTO.
 * @param dto - Potential DTO.
 * @public
 */
export declare function isLogoutNackDTO(dto: LogoutDTO): dto is EVENT_LOGOUT_NACK;

/**
 * isLogoutNackEntity.
 * @param entity - Potential entity.
 * @public
 */
export declare function isLogoutNackEntity(entity: LogoutEntity): entity is LogoutNack;

/**
 * @param error - An error.
 * @public
 */
export declare const isMappingError: (error: unknown) => error is MappingError;

/**
 * A utility to check if a pathname is a route of this micro frontend.
 *
 * @param pathname - A pathname string to check, typically location.pathname, which is used when a value is omitted.
 *
 * @public
 * @privateRemarks
 * I've just put this util in for now given there's some app level direction code in place which needs review.
 */
export declare function isMFRoute(pathname?: string): boolean;

/**
 * isDTONack.
 * @param dto - Potential NACK.
 * @public
 */
export declare function isNackDTO(dto: unknown): dto is NACK;

/**
 * isQueryParams.
 * @param params - Potential QueryParams.
 * @public
 */
export declare function isQueryParams(params: AuthMachineEventParams): params is QueryParams;

/**
 * isResetPasswordParams.
 * @remarks
 * ResetPasswordParams.requester is optional, so it is not part of the evaluation.
 * @param params - Potential ResetPasswordParams.
 * @public
 */
export declare function isResetPasswordParams(params: AuthMachineEventParams): params is ResetPasswordParams;

/**
 * @public
 */
export declare type JWTCredentials = {
    type: CredentialType_2 & CredentialType_2.JWT;
    jwt: string;
    domain: string;
};

/**
 * @public
 */
export declare const logger: Logger;

/**
 * @public
 */
export declare let LOGIN_DETAILS_URL: string;

/**
 * @public
 */
export declare let LOGIN_REFRESH_URL: string;

/**
 * @public
 */
export declare let LOGIN_URL: string;

/**
 * @public
 */
export declare interface LoginAck extends Ack {
    readonly userName: string;
    readonly updateQueue: string;
    readonly zeroMqProxyModeEnabled: boolean;
    readonly zeroMqProxyInboundPort: number;
    readonly zeroMqProxyOutboundPort: number;
    readonly userKVs: {
        [key: string]: any;
    };
    readonly details: Details;
    readonly permission: string[];
    readonly profile: string[];
}

/**
 * @public
 */
export declare interface LoginDetailsAck extends LoginAck {
}

/**
 * LoginDTO type.
 * @public
 */
export declare type LoginDTO = EVENT_LOGIN_AUTH | EVENT_LOGIN_AUTH_ACK | EVENT_LOGIN_AUTH_NACK | EVENT_LOGIN_DETAILS_ACK;

/**
 * LoginEntity type.
 * @public
 */
export declare type LoginEntity = Credentials | LoginAck | LoginDetailsAck | LoginNack;

/**
 * LoginMapper interface.
 *
 * @remarks
 * An extensible mapper for converting between login DTOs and Entities, where you can normalise data, implement derived
 * fields, validation etc.
 *
 * @example Overriding the default mapper for your application. Note the interface is the key.
 * ```ts
 * import { DefaultLoginMapper, LoginMapper } from '@genesislcap/foundation-auth';
 * import { Container, Registration } from '@microsoft/fast-foundation';
 *
 * class MyLoginMapper extends DefaultLoginMapper {
 *     // modify logic
 * }
 *
 * @customElement({...})
 * export class MyApplication extends FASTElement {
 *     @Container container!: Container;
 *     connectedCallback() {
 *         this.container.register(Registration.singleton(LoginMapper, MyLoginMapper));
 *     }
 * }
 * ```
 *
 * @public
 */
export declare interface LoginMapper extends Mapper<LoginDTO, LoginEntity> {
}

/**
 * LoginMapper DI key.
 *
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 *
 * @internal
 */
export declare const LoginMapper: InterfaceSymbol<LoginMapper>;

/**
 * @public
 */
export declare interface LoginNack extends Nack {
    readonly refreshAuthToken: string;
    readonly isMFARequired: boolean;
    readonly hasPasswordExpired: boolean;
}

/**
 * @public
 */
export declare type LoginParams = Credentials;

/**
 * @public
 */
export declare interface LOGOUT_ACK extends ACK {
    readonly OIDC_LOGOUT_URL: string;
}

/**
 * @public
 */
export declare let LOGOUT_URL: string;

/**
 * @public
 */
export declare interface LogoutAck extends Ack {
    readonly oidcLogoutUrl: string;
}

/**
 * LogoutDTO type.
 * @public
 */
export declare type LogoutDTO = LOGOUT_ACK | EVENT_LOGOUT_NACK;

/**
 * LogoutEntity type.
 * @public
 */
export declare type LogoutEntity = LogoutAck | LogoutNack;

/**
 * LogoutMapper interface.
 *
 * @remarks
 * An extensible mapper for converting between logout DTOs and Entities, where you can normalise data, implement derived
 * fields, validation etc.
 *
 * @public
 */
export declare interface LogoutMapper extends Mapper<LogoutDTO, LogoutEntity> {
}

/**
 * LogoutMapper DI key.
 *
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 *
 * @internal
 */
export declare const LogoutMapper: InterfaceSymbol<LogoutMapper>;

/**
 * @public
 */
export declare interface LogoutNack extends Nack {
}

/**
 * LogoutUtility interface.
 *
 * @remarks
 * A utility to execute a logout flow via a route change.
 *
 * @example Import the utility into any component or logic you wish to invoke a logout from.
 * ```ts
 * import { LogoutUtility } from '@genesislcap/foundation-auth/logout';
 * ...
 * @LogoutUtility private logout: LogoutUtility;
 * ...
 * this.logout.run();
 * ```
 *
 * @public
 */
export declare interface LogoutUtility {
    run(): void;
}

/**
 * LogoutUtility DI key.
 *
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 *
 * @internal
 */
export declare const LogoutUtility: InterfaceSymbol<LogoutUtility>;

/**
 * Base implementation of a routing used with the Auth class
 *
 * @internal
 */
export declare class MainRouterConfig extends RouterConfiguration<Settings> {
    private user;
    private container;
    private authConfig;
    constructor(user: User, container: Container, authConfig: AuthConfig);
    configure(): void;
    construct<T>(Type: Constructable<T>): T;
}

/**
 * DTO mapper interface.
 * @remarks
 * Both `toEntity` and `toDTO` APIs are optional by design as message direction flows are unknown.
 * @typeParam TDTO - The dto type.
 * @typeParam TEntity - The entity type.
 * @public
 */
export declare interface Mapper<TDTO, TEntity> {
    /**
     * Converts a DTO to an entity.
     * @param dto - The DTO to convert.
     * @returns The resulting entity.
     */
    toEntity?: (dto: TDTO) => TEntity;
    /**
     * Converts an entity to a DTO.
     * @param entity - The entity to convert.
     * @returns The resulting DTO.
     */
    toDTO?: (entity: Partial<TEntity>) => TDTO;
}

/**
 * MappingError.
 * @public
 */
export declare class MappingError extends Error {
    data?: unknown;
    constructor(data?: unknown, message?: string);
}

/**
 * @internal
 */
export declare interface MESSAGE {
    readonly MESSAGE_TYPE: `${MESSAGE_TYPE}`;
    readonly SOURCE_REF: string;
}

/**
 * @internal
 */
export declare interface Message {
    readonly messageType: `${MESSAGE_TYPE}`;
    readonly sourceRef: string;
}

/**
 * @internal
 */
export declare enum MESSAGE_TYPE {
    /**
     * Login
     */
    LOGIN = "EVENT_LOGIN_AUTH",
    LOGIN_ACK = "EVENT_LOGIN_AUTH_ACK",
    LOGIN_NACK = "EVENT_LOGIN_AUTH_NACK",
    LOGIN_DETAILS_ACK = "EVENT_LOGIN_DETAILS_ACK",
    LOGIN_DETAILS_NACK = "EVENT_LOGIN_DETAILS_NACK",
    /**
     * Logout
     */
    LOGOUT_ACK = "LOGOUT_ACK",
    LOGOUT_NACK = "EVENT_LOGOUT_NACK",
    /**
     * Password management
     */
    FORGOT_PASSWORD = "EVENT_SELF_SERVICE_PASSWORD_RESET",
    CHANGE_PASSWORD = "EVENT_CHANGE_USER_PASSWORD",
    RESET_PASSWORD = "EVENT_PASSWORD_RESET_ACTION",
    /**
     * Generic
     */
    EVENT_NACK = "EVENT_NACK"
}

/**
 * @public
 */
export declare interface MessageMapper<TLookup extends MessageMapperLookup, K extends keyof TLookup = keyof TLookup> extends Pick<Map<K, TLookup[K]>, 'get' | 'has' | 'delete' | 'clear' | 'size'> {
    /**
     * Set a mapper by message type.
     * @param key - The message type as key.
     * @param mapper - The mapper.
     *
     * @public
     */
    set(key: K, mapper: TLookup[K]): void;
}

/**
 * @public
 */
export declare type MessageMapperLookup = Record<string, Mapper<unknown, unknown>>;

/**
 * @remarks
 * Will be sourced from MFA_CODE in url params.
 * @public
 */
export declare type MFACredentials = {
    type: CredentialType_2 & CredentialType_2.MFA;
    mfaToken: string;
};

/**
 * @internal
 */
export declare interface NACK extends MESSAGE {
    readonly ERROR: NACK_ERROR_WARNING[];
    readonly WARNING: NACK_ERROR_WARNING[];
}

/**
 * @internal
 */
export declare interface Nack extends Message {
    readonly error: NackErrorWarning[];
    readonly warning: NackErrorWarning[];
}

/**
 * @internal
 */
export declare interface NACK_ERROR_WARNING {
    readonly '@type': string;
    readonly CODE: string;
    readonly STATUS_CODE: string;
    readonly TEXT: string;
}

/**
 * @internal
 */
export declare interface NackErrorWarning {
    readonly type: string;
    readonly code: string;
    readonly statusCode: string;
    readonly text: string;
}

/**
 * @internal
 */
export declare const organisationField: <T extends BaseRoute>() => ViewTemplate<T, any>;

/**
 * @internal
 */
export declare const password2Field: <T extends BaseRoute>(type: 'new' | 'confirmation') => ViewTemplate<T, any>;

/**
 * @internal
 */
export declare const passwordField: <T extends BaseRoute>(label?: string) => ViewTemplate<T, any>;

/**
 * PasswordManagementDTO type.
 * @public
 */
export declare type PasswordManagementDTO = EVENT_SELF_SERVICE_PASSWORD_RESET | EVENT_CHANGE_USER_PASSWORD | EVENT_PASSWORD_RESET_ACTION;

/**
 * PasswordManagementEntity type.
 * @public
 */
export declare type PasswordManagementEntity = ForgotPasswordParams | ChangePasswordParams | ResetPasswordParams;

/**
 * PasswordManagementMapper interface.
 *
 * @remarks
 * A mapper for the self-service password management flows.
 *
 * @public
 */
export declare interface PasswordManagementMapper extends Mapper<PasswordManagementDTO, PasswordManagementEntity> {
}

/**
 * PasswordManagementMapper DI key.
 *
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 *
 * @internal
 */
export declare const PasswordManagementMapper: InterfaceSymbol<PasswordManagementMapper>;

/**
 * @public
 */
export declare interface Product {
    readonly name: string;
    readonly version: string;
}

/**
 * @public
 */
declare interface Product_2 {
    readonly NAME: string;
    readonly VERSION: string;
}

/**
 * @public
 */
export declare type QueryParams = {
    SSO_TOKEN?: string;
    MFA_CODE?: string;
};

/**
 * @public
 */
export declare type RefreshCredentials = {
    type: CredentialType_2 & CredentialType_2.REFRESH;
    username: string;
    refreshToken: string;
};

/**
 * @public
 */
export declare let RESET_PASSWORD_URL: string;

/**
 * @public
 */
export declare type ResetPasswordParams = {
    username: string;
    resetToken: string;
    newPassword: string;
    requester?: string;
};

/**
 * @public
 */
export declare const Routes: {
    readonly login: "login";
    readonly logout: "logout";
    readonly 'request-account': "request-account";
    readonly 'reset-password': "reset-password";
    readonly 'forgot-password': "forgot-password";
    readonly verify: "verify";
    readonly protected: "protected";
    readonly 'not-found': "not-found";
};

/**
 * @public
 */
export declare type Routes = (typeof Routes)[keyof typeof Routes];

/**
 * @internal
 */
export declare const selectEmit: <K extends KeysMatching<EventMap, string>>(type: K, options?: EmitOptions) => Binding<any, any, any>;

/**
 * Defines the parameters you may set on the routes.
 *
 * @remarks
 * See the example in the {@link Auth} class in the router's `configure` method for usage. All parameters are Optional.
 *
 * @public
 */
export declare type Settings = {
    /**
     * Controls whether the user has to be logged in to view.
     */
    public?: boolean;
};

/**
 * @internal
 */
export declare const showPasswordsCheckbox: <T extends BaseRoute>() => ViewTemplate<T, any>;

/**
 * @public
 */
export declare let SOCKET_URL: string;

/**
 * @public
 */
export declare type SSOConfig = {
    /**
     * Optionally toggle the SSO journey on/off by default.
     */
    toggled?: boolean;
    /**
     * The identity providers path under the current host.
     *
     * @example
     * ```ts
     * identityProvidersPath: 'sso/list'
     * ```
     */
    identityProvidersPath: string;
};

/**
 * @public
 */
export declare type SSOCredentials = {
    type: CredentialType_2 & CredentialType_2.SSO;
    ssoToken: string;
};

/**
 * @internal
 * @privateRemarks
 * This is used during development of this micro frontend.
 */
export declare const standaloneDefinition: PartialFASTElementDefinition;

/**
 * @public
 * @privateRemarks
 * Options can be used to target unknown component tags in the css, such as:
 * @example unknown target
 * ```
 * const buttonTag = tagFor(options.button);
 * ...
 * ${buttonTag} {
 *   width: 200px;
 * }
 * ```
 */
export declare const styles: (options: TemplateOptions) => ElementStyles;

/**
 * @internal
 */
export declare const submitButton: <T extends ConfigHost>(label: string, dataTestId?: string, disabled?: boolean) => ViewTemplate<T, any>;

/**
 * @public
 */
export declare interface System {
    readonly date: string;
}

/**
 * @public
 */
declare interface System_2 {
    readonly DATE: string;
}

/**
 * @public
 */
export declare const template: (options: TemplateOptions) => ViewTemplate<Auth, any>;

/**
 * @beta
 * @privateRemarks
 * The CLI can be used to monitor what is in use and needs a mapping.
 */
export declare type TemplateComponents = {
    anchor: TemplateElementDependency;
    button: TemplateElementDependency;
    card: TemplateElementDependency;
    checkbox: TemplateElementDependency;
    listboxOption: TemplateElementDependency;
    provider: TemplateElementDependency;
    router: TemplateElementDependency;
    select: TemplateElementDependency;
    textField: TemplateElementDependency;
};

/**
 * @beta
 */
export declare type TemplateOptions = TemplateComponents & {
    somePartial?: string | SyntheticViewTemplate;
};

/**
 * User interface.
 *
 * @remarks
 * The user singleton, which always exists in either an anonymous or authenticated mode.
 *
 * @privateRemarks
 * Providing `username` and `userName` for backwards compatability.
 *
 * @example
 * ```ts
 * import { User } from '@genesislcap/foundation-auth/user';
 * ...
 * @User private user: User
 * ```
 *
 * @public
 */
export declare interface User extends UserPathHistory, UserActionHistory {
    readonly isAuthenticated: boolean;
    readonly isAnonymous: boolean;
    readonly userKVs: {
        [key: string]: any;
    };
    readonly details: Details;
    readonly permission: string[];
    readonly profile: string[];
    readonly sourceRef: string;
    readonly userName: string;
    readonly username: string;
    /**
     * @param entity - The LoginAck used to populate the User.
     */
    set(entity: Partial<LoginAck>): this;
    unset(): this;
    isAdmin(): boolean;
    isBanned(): boolean;
    /**
     * @param permission - A permission string or an array of permission strings to check.
     */
    hasPermission(permission: string | string[]): boolean;
    /**
     * @param profile - A profile string or an array of profile strings to check.
     */
    hasProfile(profile: string | string[]): boolean;
    /**
     * @example
     * ```ts
     * import type { UserAuthenticationChangeEvent } from '@genesislcap/foundation-auth/user';
     * ...
     * this.user.addAuthenticationChangeListener((event: UserAuthenticationChangeEvent) => {
     *   console.log('User authenticated?', event.detail);
     * });
     * ```
     *
     * @param listener - A listener function.
     */
    addAuthenticationChangeListener(listener: Listener<UserAuthenticationChangeEvent>): void;
}

/**
 * User DI key.
 *
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 *
 * @internal
 */
export declare const User: InterfaceSymbol<User>;

/**
 * UserActionHistory.
 *
 * @remarks
 * APIs to track a user's action history.
 *
 * @privateRemarks
 * Integrate with foundation analytics? Users could then simply call `user.trackAction` and we could engage analytics.
 * We should move analytics out of comms first.
 *
 * @public
 */
export declare interface UserActionHistory {
    /**
     * Array of actions that have been tracked.
     */
    readonly actionHistory: unknown[];
    /**
     * Track an action.
     */
    trackAction<TDetails = unknown>(details: TDetails): void;
    /**
     * Clears action history.
     */
    clearActions(): void;
    /**
     * @returns The last stored action.
     */
    lastAction(): unknown;
}

/**
 * UserAuthenticationChangeEvent.
 *
 * @remarks
 * Detail will either be `true` or `false` to indicate authentication status.
 *
 * @public
 */
export declare type UserAuthenticationChangeEvent = CustomEvent<boolean>;

/**
 * UserAuthenticationChangeType.
 * @public
 */
export declare const UserAuthenticationChangeType = "user-authentication-change";

/**
 * UserConfig DI interface.
 *
 * @public
 */
export declare interface UserConfig {
    /**
     * Exclude certain actions from tracking.
     */
    trackActionExclusions: unknown[];
    /**
     * Exclude certain paths from tracking.
     */
    trackPathExclusions: string[];
}

/**
 * UserConfig DI key.
 *
 * @internal
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 */
export declare const UserConfig: InterfaceSymbol<UserConfig>;

/**
 * @internal
 */
export declare const usernameField: <T extends BaseRoute>() => ViewTemplate<T, any>;

/**
 * UserPathHistory.
 *
 * @remarks
 * APIs to track a user's path history. Includes the pathname, search and hash only.
 * This is not intended proxy or replace the History API.
 *
 * @privateRemarks
 * Integrate with foundation analytics? Users could then simply call `user.trackPath` and we could engage analytics.
 * We should move analytics out of comms first.
 *
 * @public
 */
export declare interface UserPathHistory {
    /**
     * Array of paths that have been tracked.
     */
    readonly pathHistory: string[];
    /**
     * Track current path.
     */
    trackPath(): string;
    /**
     * Clears path history.
     */
    clearPaths(): void;
    /**
     * May be used to return to a target path after authentication.
     * @returns The last stored path.
     */
    lastPath(): string | undefined;
}

export { }
